package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@$!`0````````````(``P`!````U)@$"#0````DKP```````#0`(``(
M`"@`'``;``8````T````-(`$"#2`!`@``0````$```4````$`````P```#0!
M```T@00(-($$"!,````3````!`````$````!``````````"`!`@`@`0(E$X`
M`)1.```%`````!````$`````4````-`$"`#0!`@D7@``L&X```8`````$```
M`@```!10```4T`0(%-`$"`@!```(`0``!@````0````$````2`$``$B!!`A(
M@00(1````$0````$````!````%#E=&1@2```8,@$"&#(!`C\````_`````0`
M```$````4>5T9```````````````````````````!@````0````O;&EB+VQD
M+6QI;G5X+G-O+C(```0````0`````0```$=.50```````@````8````A````
M!````!0````#````1TY5`#*GHN5_?95QMYY.G`]E?GY1H-^8)0```$,````(
M````"``````<$`0E0`2".`%``:*&`:A````"2R@$*3BB,D>*!`P(0P```$4`
M``````````````````!'````20```$H`````````2P```$P```!.````3P``
M`%````!1`````````%(``````````````%,```!4````5P``````````````
M6````%H```!;````70````````!?````80``````````````8P```&0```!E
M`````````,C5LG%9Z.WLSMY'+:/@^TGJT^\.I]VC:R_%F[;;S>.>A_F<@5:D
MFY9K"4/6.?*+'`TZEPO%B060#13BGB'_Y`X+BA!7Q+F<0&I_FGRS`8MO?ZF<
MFV[%WQ_9<5@<N^.2?*Q+X\#59-1\X*<""C-BV^UZ\$IK9Z_,9D)%U>SC1\8!
M?4&.Q</E/RSRV],=^J%L8+F-\0X`````````````````````Z`(`````````
M````$@```(X#`````````````!(```!0`@`````````````2````+P0`````
M````````$@```'\#`````````````!(```"V```````````````2`````P,`
M````````````$@```*,``````````````!(```#O`@`````````````2````
M:P$`````````````$@```+$``````````````!(```"?`@`````````````2
M````/`,`````````````$@```+`"`````````````!(```!Q````````````
M```2````3`,`````````````$@```$,#`````````````!(```!=`0``````
M```````2````F`$`````````````$@```'\``````````````!(````O````
M```````````2````;@(`````````````$@```$@"`````````````!(```#,
M`@`````````````2````"P$`````````````$@```+T"`````````````!(`
M```7`0`````````````2````N@$`````````````$@```%,#````````````
M`!(````,```````````````@````@`(`````````````$@```&`#````````
M`````!(```")`0`````````````2````V@(`````````````$@```)4#````
M`````````!(````P`@`````````````2````W@``````````````$@```%P`
M`````````````!(````]```````````````2````X0(`````````````$@``
M`+<"`````````````!(```"-`@`````````````2````-P(`````````````
M$@```,4"`````````````!(````\`0`````````````2````T@``````````
M````$@````H#`````````````!(```!(```````````````2````'@$`````
M````````$@```(<#`````````````!(```#3`@`````````````2````B@``
M````````````$@```!L``````````````"````#K```````````````2````
M4P``````````````$@```&<#`````````````!(```#U`@`````````````2
M````NP``````````````$@```(4"`````````````!(````K`P``````````
M```2````%@(`````````````$@```!@#`````````````!(````J`@``````
M```````2````E@(`````````````$@```",#`````````````!(```!Q`P``
M```````````2````2@$``&"5!`@`````$@```)T$```8Q00(!````!$`#P!=
M!```X+,$"$4+```2``T`I`0``,"P!`B?`0``$@`-``8$``#\Q`0(`````!(`
M#@"I`P``0"X%"`0````A`!D`#`0``+"M!`@%````$@`-`(T$``!0Q`0(80``
M`!(`#0#Z````$)8$"``````2````F````$@N!0@$````$0`9`&H$``!`T@0(
M`````!``&``U`P``1"X%"`0````1`!D`;`0``$#2!`@`````(``8`*@#``!`
M+@4(!````"$`&0#\`P``P,0$"`(````2``T`N00``,"M!`C$`0``$@`-`"\!
M``!@+@4(`0```!$`&0"G`P``0"X%"`0````1`!D`H@,``/"6!`CB`0``$@`-
M`-@$``!@L@0(0@```!(`#0`=!```L+($""0````2``T`.`0``$##!`AX````
M$@`-`+@#```D+@4(`````!``\?_$`P``L#X%"``````0`/'_7P(``!S%!`@$
M````$0`/``(%```POP0("P0``!(`#0!W!```T*P$"-X````2``T`<`0``-28
M!`@`````$@`-`*H!```PDP0(`````!(```!1!```P*\$"/(````2``T`L0,`
M`"0N!0@`````$`#Q_T0$``"0KP0(+P```!(`#0#F!```P,,$"$D````2``T`
ML00``#"L!`@T````$@`-`'H!``!A+@4($P```!$`&0#&!```X+($"``!```2
M``T`LP0``&22!`@`````$@`+``!L:6)P97)L+G-O`%]?9VUO;E]S=&%R=%]?
M`%]*=E]296=I<W1E<D-L87-S97,`4&5R;%]D;W5N=VEN9`!097)L7VYE=UA3
M`'!E<FQ?<&%R<V4`<&5R;%]R=6X`4&5R;%]C<F]A:U]N;V-O;G1E>'0`<&5R
M;%]D97-T<G5C=`!P97)L7V%L;&]C`%!E<FQ?879?9F5T8V@`4$Q?=&AR7VME
M>0!097)L7V%V7W-H:69T`'!E<FQ?9G)E90!097)L7W-A=F5?9&5S=')U8W1O
M<E]X`%!E<FQ?;6=?<V5T`%!E<FQ?;F5W4U9P=@!097)L7W-V7W-E='!V;@!0
M97)L7V%T9F]R:U]L;V-K`%!E<FQ?<V%F97-Y<VUA;&QO8P!097)L7VYE=UA3
M7V9L86=S`%!,7V1O7W5N9'5M<`!097)L7W-Y<U]T97)M`%!E<FQ?871F;W)K
M7W5N;&]C:P!097)L7W-V7W-E='!V`'!E<FQ?8V]N<W1R=6-T`%!,7VUE;6]R
M>5]W<F%P`%!E<FQ?<WES7VEN:70S`%!E<FQ?<W9?,G!V7V9L86=S`&)O;W1?
M1'EN84QO861E<@!097)L7V=V7V9E=&-H<'8`;&EB;G-L+G-O+C$`;&EB9&PN
M<V\N,@!L:6)M+G-O+C8`;&EB8W)Y<'0N<V\N,0!L:6)U=&EL+G-O+C$`;&EB
M<'1H<F5A9"YS;RXP`'!T:')E861?9V5T<W!E8VEF:6,`8VQO<V4`;W!E;C8T
M`%]?97)R;F]?;&]C871I;VX`;'-E96LV-`!R96%D`&QI8F,N<V\N-@!?24]?
M<W1D:6Y?=7-E9`!?7W)E9VES=&5R7V%T9F]R:P!E>&ET`'-T<FYC;7``7U]S
M=')D=7``8VQO<V5D:7(`7U]S=&%C:U]C:&M?9F%I;`!U;FQI;FL`;6MD:7(`
M<F5A;&QO8P!M96UC:'(`9V5T<&ED`'-T<G1O:P!S=')L96X`;65M<V5T`'-T
M<G-T<@!R;61I<@!?7V9P<FEN=&9?8VAK`&UE;6-P>0!?7W-T<FYC<'E?8VAK
M`%]?;'AS=&%T-C0`;W!E;F1I<@!?7WAS=&%T-C0`<W1D97)R`&=E='5I9`!R
M96%D;&EN:P!E>&5C=G``7U]M96UC<'E?8VAK`'-T<F-H<@!R96%D9&ER-C0`
M7U]S<')I;G1F7V-H:P!M96UM;W9E`&%C8V5S<P!S=')C;7``7U]L:6)C7W-T
M87)T7VUA:6X`7U]E;G9I<F]N`%]E9&%T80!?7V)S<U]S=&%R=`!?96YD`"]U
M<W(O;&EB+W!E<FPU+S4N,30N,B]I,S@V+6QI;G5X+71H<F5A9"UM=6QT:2]#
M3U)%`%]?;&EB8U]C<W5?9FEN:0!P87)?8W5R<F5N=%]E>&5C`&=E=%]U<V5R
M;F%M95]F<F]M7V=E='!W=6ED`'!A<E]C;&5A;G5P`'!A<E]B87-E;F%M90!P
M87)?9&ER;F%M90!P87)?;6MT;7!D:7(`7U]D871A7W-T87)T`'!A<E]C=7)R
M96YT7V5X96-?<')O8P!?7VQI8F-?8W-U7VEN:70`7V9P7VAW`'!A<E]I;FET
M7V5N=@!X<U]I;FET`'!A<E]F:6YD<')O9P!P87)?<V5T=7!?;&EB<&%T:`!P
M87)?96YV7V-L96%N`%A37TEN=&5R;F%L<U]005)?0TQ%05)35$%#2P!84U])
M;G1E<FYA;'-?4$%27T)/3U0`1TQ)0D-?,BXR`$=,24)#7S(N,`!'3$E"0U\R
M+C,N-`!'3$E"0U\R+C,N,@!'3$E"0U\R+C0````"``(``P`"``(``@`"````
M`@``````!``"``(````"``(````````````%``8``@````(``@````<````"
M``(````"``(`!@`````````"``(``@`#``(```````<```````(``@``````
M``````@`!P````(`"``#``@``P`"``(`!P````$``0`!``$``@`!``$`````
M``$``@`!``(``0`!`````@`!``$``0`!``$``0`!``$``0`!`````0`!``$`
M`0`!`````0`!`````0`"``8"```0````,````!)I:0T```8`&`4``!`````0
M:6D-```#`"(%`````````0`%`%4"```0`````````!)I:0T```@`&`4``!``
M``!T&6D)```'`"P%```0````<AEI"0``!0`X!0``$````!1I:0T```0`1`4`
M`!`````0:6D-```"`"(%````````'-$$"`8>``!`+@4(!50``$0N!0@%3@``
M2"X%"`5,``!@+@4(!5,``&$N!0@%90``+-$$"`<!```PT00(!P(``#31!`@'
M`P``.-$$"`<$```\T00(!P4``$#1!`@'!@``1-$$"`<'``!(T00(!P@``$S1
M!`@'7P``4-$$"`<)``!4T00(!PH``%C1!`@'"P``7-$$"`<,``!@T00(!PT`
M`&31!`@'#@``:-$$"`</``!LT00(!Q```'#1!`@'$0``=-$$"`<2``!XT00(
M!Q,``'S1!`@'%```@-$$"`<5``"$T00(!Q8``(C1!`@'%P``C-$$"`<8``"0
MT00(!QD``)31!`@'&@``F-$$"`<;``"<T00(!QP``*#1!`@''0``I-$$"`<>
M``"HT00(!Q\``*S1!`@'(```L-$$"`<A``"TT00(!R(``+C1!`@'(P``O-$$
M"`<D``#`T00(!R4``,31!`@')@``R-$$"`<G``#,T00(!R@``-#1!`@'*0``
MU-$$"`<J``#8T00(!T,``-S1!`@'*P``X-$$"`<L``#DT00(!RT``.C1!`@'
M+@``[-$$"`<O``#PT00(!S```/31!`@',0``^-$$"`<R``#\T00(!S,```#2
M!`@'-```!-($"`=+```(T@0(!S8```S2!`@'-P``$-($"`<X```4T@0(!SD`
M`!C2!`@'.@``'-($"`<[```@T@0(!SP``"32!`@'/0``*-($"`<^```LT@0(
M!S\``##2!`@'0```--($"`=!```XT@0(!T(``%.#[`CH`````%N!P[,^``"+
M@_S___^%P'0%Z`T"``#HV`8``.A#,@``@\0(6\,``````````````````/\U
M)-$$"/\E*-$$"`````#_)2S1!`AH`````.G@_____R4PT00(:`@```#IT/__
M__\E--$$"&@0````Z<#_____)3C1!`AH&````.FP_____R4\T00(:"````#I
MH/____\E0-$$"&@H````Z9#_____)431!`AH,````.F`_____R5(T00(:#@`
M``#I</____\E3-$$"&A`````Z6#_____)5#1!`AH2````.E0_____R54T00(
M:%````#I0/____\E6-$$"&A8````Z3#_____)5S1!`AH8````.D@_____R5@
MT00(:&@```#I$/____\E9-$$"&AP````Z0#_____)6C1!`AH>````.GP_O__
M_R5LT00(:(````#IX/[___\E<-$$"&B(````Z=#^____)731!`AHD````.G`
M_O___R5XT00(:)@```#IL/[___\E?-$$"&B@````Z:#^____)8#1!`AHJ```
M`.F0_O___R6$T00(:+````#I@/[___\EB-$$"&BX````Z7#^____)8S1!`AH
MP````.E@_O___R60T00(:,@```#I4/[___\EE-$$"&C0````Z4#^____)9C1
M!`AHV````.DP_O___R6<T00(:.````#I(/[___\EH-$$"&CH````Z1#^____
M):31!`AH\````.D`_O___R6HT00(:/@```#I\/W___\EK-$$"&@``0``Z>#]
M____);#1!`AH"`$``.G0_?___R6TT00(:!`!``#IP/W___\EN-$$"&@8`0``
MZ;#]____);S1!`AH(`$``.F@_?___R7`T00(:"@!``#ID/W___\EQ-$$"&@P
M`0``Z8#]____)<C1!`AH.`$``.EP_?___R7,T00(:$`!``#I8/W___\ET-$$
M"&A(`0``Z5#]____)=31!`AH4`$``.E`_?___R78T00(:%@!``#I,/W___\E
MW-$$"&A@`0``Z2#]____)>#1!`AH:`$``.D0_?___R7DT00(:'`!``#I`/W_
M__\EZ-$$"&AX`0``Z?#\____)>S1!`AH@`$``.G@_/___R7PT00(:(@!``#I
MT/S___\E]-$$"&B0`0``Z<#\____)?C1!`AHF`$``.FP_/___R7\T00(:*`!
M``#IH/S___\E`-($"&BH`0``Z9#\____)032!`AHL`$``.F`_/___R4(T@0(
M:+@!``#I</S___\E#-($"&C``0``Z6#\____)1#2!`AHR`$``.E0_/___R44
MT@0(:-`!``#I0/S___\E&-($"&C8`0``Z3#\____)1S2!`AHX`$``.D@_/__
M_R4@T@0(:.@!``#I$/S___\E)-($"&CP`0``Z0#\____)2C2!`AH^`$``.GP
M^____R4LT@0(:``"``#IX/O___\E,-($"&@(`@``Z=#[____)332!`AH$`(`
M`.G`^____R4XT@0(:!@"``#IL/O__U6)Y593@^3P@^PPC440B40D"(U%#(E$
M)`2-10B)!"3HK/W__\=$)`A@E00(QT0D!&"5!`C'!"00E@0(Z.`L``"`/6`N
M!0@`=2[HLOS__X7`HZP^!0@/A'L!``")!"3H_?O__Z%(+@4(B00DZ##____&
M@``#````H4@N!0@QVXD$).@:____@(A#`P```J%(+@4(B00DZ`;___^+50B#
MP@6`B$,#```!B50D*(E<)"S?;"0HV`50R`0(W058R`0(V<G:Z=_@G@^']@``
M`,'B`HD4).AY_/__BW4,BUT(QP6D/@4(!````(L6@_L!HZ`^!0C'0`0%QP0(
MB1#'0`B`T@0(QT`,",<$"'X4N@$```"0BPR6B4R0#(/"`3G:=?*#PP/'!)@`
M````B40D#*&L/@4(B5PD",=$)!``````QT0D!'"L!`B)!"3H@_W__X7`B<-T
M-J&L/@4(B00DZ%#[__^XR<4$".CV#```A<!T+*&L/@4(B00DZ/7Z___H(/W_
M_XUE^(G86UY=PZ&L/@4(B00DZ*K]__^)P^NYH:@^!0B%P'0*B00DZ*4J``#K
MP;A^Q00(Z*D,``"%P*.H/@4(=*[KX<=$)`1A+@4(QP0D><4$".A*_/__QP0D
M`0```.C.^___D)`Q[5Z)X8/D\%!44FC`Q`0(:%#$!`A15FCPE@0(Z.O[___T
MD)"0D)"0D)"0D%6)Y5.#[`2`/70N!0@`=3^A>"X%"+L,T`0(@>L(T`0(P?L"
M@^L!.=AS'HVV`````(/``:-X+@4(_Q2%"-`$"*%X+@4(.=ARZ,8%="X%"`&#
MQ`1;7<.-="8`C;PG`````%6)Y8/L&*$0T`0(A<!T$K@`````A<!T"<<$)!#0
M!`C_T,G#D)"0D)"0D)"0D)"0D%6)P5>#P1Q64X'L6`$``(E$)!0QP(UV`(L4
M@0_*B52$&(/``8/X$'7OC50D3(V,)$P!``"-="8`BT+L,P(S0M0S0LS!R!^)
M0@R#P@0YRG7HBT0D%(M4)!B+`(E$)!"+1"04BUPD$(M`!(E$)`R+1"04BTPD
M#(M`",'!'B'+B40D"(M$)!2+0`R)1"0$BT0D%(M`$`'"B00DBT0D$,'`!8V\
M`IEY@EJ+1"0,BU0D""-4)`SWT"-$)`0)T(M4)`0!QXM$)!`#5"0<B?WWT"-$
M)`@)V(M<)`B-M`*9>8):B?B+5"00P<`%`<8#7"0@B?#!P`7!PAZ-G`.9>8):
MB?CWT"'5(<@)Z(GU`<.)\,'''O?0`TPD)"'](=`)Z(G=C8P!F7F"6HG8P<`%
M`<$#5"0HB<C!P`7!QAZ-E`*9>8):B=CWT"'U(?@)Z(G-`<*)R,'#'O?0`WPD
M+"'=(?`)Z(G5C;P'F7F"6HG0P<`%`<<#="0PB?C!P`7!P1Z-M`:9>8):B=#W
MT"'-(=@)Z(G]`<:)^,'"'O?0`UPD-"'5(<@)Z(GUC9P#F7F"6HGPP<`%`<,#
M3"0XB=C!P`7!QQZ-C`&9>8):B?#WT"'](=`)Z(G=`<&)V,'&'O?0`U0D/"'U
M(?@)Z(G-C90"F7F"6HG(P<`%`<(#?"1`B=#!P`7!PQZ-O`>9>8):B<CWT"'=
M(?`)Z(G5`<>)T,'!'O?0`W0D1"'-(=@)Z(G]C;0&F7F"6HGXP<`%`<8#7"1(
MB?#!P`7!PAZ-G`.9>8):B?CWT"'5(<@)Z(GU`<.)\,'''O?0`TPD3"'](=`)
MZ(G=C8P!F7F"6HG8P<`%`<$#5"10B<C!QA[!P`4A]8V4`IEY@EJ)V/?0(?@)
MZ(G-`<*)R,'#'O?0`WPD5"'=(?`)Z(G5C;P'F7F"6HG0P<`%`<<#="18B?C!
MP`7!P1Z-M`:9>8):B=#WT"'-(=@)Z(G]`<:)^,'"'O?0`UPD7"'5(<@)Z(GU
MC9P#F7F"6HGPP<`%`<,#3"1@B=C!P`7!QQZ-C`&9>8):B?#WT"'](=`)Z(G=
M`<&)V,'&'O?0`U0D9"'U(?@)Z(V4`IEY@EJ)R,'#'L'`!0'"B=@#?"1H,?`Q
MR,'!'HV\!Z'KV6Z)T,'`!0'XB<\#="1L,=\QU\'"'HV\/J'KV6Z)QL'&!0'^
MB=<#7"1P,<\QQ\'`'HV\.Z'KV6Z)\\'#!0'[B<<#3"1T,=<Q]\'&'HV\.:'K
MV6Z)V<'!!0'YB?<#5"1X,<<QW\'#'HV\.J'KV6Z)RL'"!0'ZB=\#1"1\,?<Q
MS\'!'HV\.*'KV6Z)T,'`!0'XB<\#M"2`````,=\QU\'"'HV\/J'KV6Z)QL'&
M!0'^B=<#G"2$````,<\QQ\'`'HV\.Z'KV6Z)\\'#!0'[B<<#C"2(````,=<Q
M]\'&'HV\.:'KV6Z)V<'!!0'YB?<#E"2,````,<<QWXV\.J'KV6Z)RL'"!0'Z
MP<,>`X0DD````(G?,?<QSXV\.*'KV6Z)T,'!'L'`!0'XB<\#M"24````,=\Q
MU\'"'HV\/J'KV6Z)QL'&!0'^B=<#G"28````,<\QQ\'`'HV\.Z'KV6Z)\\'#
M!0'[B<<#C"2<````,=<Q]\'&'HV\.:'KV6Z)V<'!!0'YB?<#E"2@````,<<Q
MW\'#'HV\.J'KV6Z)RL'"!0'ZB=\#A"2D````,?<QS\'!'HV\.*'KV6Z)T,'`
M!0'XB<\#M"2H````,=\QU\'"'HV\/J'KV6Z)QL'&!0'^B=<#G"2L````,<\Q
MQ\'`'HV\.Z'KV6Z)\\'#!0'[B<<#C"2P````,=<Q]\'&'HV\.:'KV6Z)V<'!
M!0'YB?<#E"2T````,<<QW\'#'HV\.J'KV6Z)RL'"!8G=`?J+O"2X````(?4!
MQXG8"?`AR`GHC;P'W+P;CXG0P<`%`?B+O"2\````P<$>B<TAW0'WB<X)WB'6
M">Z-O#?<O!N/B<;!Q@4!_HN\),````#!PAZ)U2'-`=^)TPG+(<,)ZXV\']R\
M&X^)\\'#!0'[B[PDQ````,'`'HG%(=4!SXG!"=$A\0GIC;P/W+P;CXG9P<$%
M`?F+O"3(````P<8>B?4AQ0'7B?()PB':">J-O!?<O!N/B<K!P@4!^HN\),P`
M``#!PQZ)W2'U`<>)V`GP(<@)Z(V\!]R\&X^)T,'`!0'XB[PDT````,'!'HG-
M(=T!]XG."=XAU@GNC;PWW+P;CXG&P<8%`?Z+O"34````P<(>B=4AS0'?B=,)
MRR'#">N-O!_<O!N/B?/!PP4!^XN\)-@```#!P!Z)Q2'5`<^)P0G1(?$)Z8V\
M#]R\&X^)V<'!!0'YB[PDW````,'&'HGU(<4!UXGR"<(AV@GJC;P7W+P;CXG*
MP<(%`?J+O"3@````P<,>B=TA]0''B=@)\"'(">B-O`?<O!N/B=#!P`4!^(N\
M).0```#!P1Z)S2'=`?>)S@G>(=8)[HV\-]R\&X^)QL'&!0'^B[PDZ````,'"
M'HG5(<T!WXG3"<LAPPGKC;P?W+P;CXGSP<,%`?N+O"3L````P<`>B<4AU0'/
MB<$)T2'Q">F-O`_<O!N/B=G!P04!^8N\)/````#!QAZ)]2'%`=>)\@G"(=H)
MZHV\%]R\&X^)RL'"!0'ZB[PD]````,'#'HG=(?4!QXG8"?`AR`GHC;P'W+P;
MCXG0P<`%`?B+O"3X````P<$>B<TAW0'WB<X)WB'6">Z-O#?<O!N/B<;!Q@4!
M_HN\)/P```#!PAZ)U0'?B=,)RR'-(<,)ZXV\']R\&X^)\\'#!0'[B[PD``$`
M`,'`'HG%(=4!SXG!"=$A\0GIC;P/W+P;CXG9P<$%`?F+O"0$`0``P<8>B?4A
MQ0'7B?()PB':">J-O!?<O!N/B<K!PQ[!P@4!UXG:`X0D"`$``#'R,<K!P1Z-
ME!#6P6+*B?C!P`4!T(G*`[0D#`$``#':,?J-M!;6P6+*B<+!P@4!\HG^P<8>
M`YPD$`$``(GW,<\QQXV\.];!8LJ)T\'`'L'#!0'[B<<#C"04`0``,?<QU\'"
M'HV\.=;!8LJ)V<'!!0'/B=$#M"08`0``,<$QV<'#'HVT#M;!8LJ)^<'!!0'.
MB=D#A"0<`0``,=$Q^0.4)"`!``"-C`C6P6+*B?#!P`4!P8GXP<`>B<<QWS'W
MC;PZUL%BRHG*P<8>P<(%`=>)\@.<)"0!```QPC'*P<$>C9P3UL%BRHGZP<(%
M`=J)RP.$)"@!```Q\S'[P<<>C9P8UL%BRHG0P<`%`<.)^`.T)"P!```QR#'0
MP<(>C;0&UL%BRHG8P<`%`?")U@.,)#`!```Q_C'>P<,>C;0QUL%BRHG!P<$%
M`<Z)V0.\)#0!```QT3'!P<`>C;P/UL%BRHGQP<$%`?F)QP.4)#@!```QWS'W
MC;PZUL%BRHG*P<(%P<8>`=<#G"0\`0``B?(QPC'*C9P3UL%BRHGZP<$>P<(%
M`=J)RP.$)$`!```Q\S'[P<<>C9P8UL%BRHG0P<`%`<.)^`.T)$0!```QR#'0
MP<(>C;0&UL%BRHG8P<`%`?")U@.,)$@!```Q_C'>P<,>C;0QUL%BRHG!P<$%
M`?&)W@.\)$P!```QUC'&P<`>C;PWUL%BRHG.P<8%`?Z)QP.4)%`!```QWS'/
MP<$>C;PZUL%BRHGRP<(%`?J+?"00`[PD5`$``(V\.];!8LJ)RS'#,?,!^XG7
MP<<%`?N+?"04P<8>B1\#5"0,`TPD!`,$)(E7!(M4)`B)3PR)1Q`!\HE7"('$
M6`$``%M>7UW#C;0F`````%575E.)PX/L+(7`B50D''1*H4`N!0B%P(E$)!AT
M/0^V`SP]=4,Q[8M$)!B+,#'`A?9T*HM\)!B0B6PD"(E<)`2)-"3HB/'__X7`
M=0:`/"X]=#:#QP2+-X7V==TQP(/$+%M>7UW#C78`A,!TN8G=@\4!#[9%`#P]
M=`2$P'7Q*=WKIHVT)@````"+1"0<*WPD&,'_`HDX@\0LC40N`5M>7UW#ZPV0
MD)"0D)"0D)"0D)"0@^P<C50D#.A$____@\0<PU.)PX/L&(U4)`R)V.@O____
MA<!T-HUV`(L50"X%"(M$)`R-!(*+4`2%THD0=-AFD(/`!(M0!(72B1!U](U4
M)`R)V.CY_O__A<!US8/$&%O#5E.#[!2A2"X%"(D$).C.\/__BX!P`0``BW`$
MH4@N!0B)!"3HN/#__P^VF/@"``"A2"X%"(/C?XD$).BA\/__BT`$#[=`$,'@
M!PG89HE&`J%(+@4(B00DZ(3P__^+@'`!``"+6`2A2"X%"(D$).AN\/__QT0D
M"`````#'1"0$_\8$"(D$).C&[O__B4,<H4@N!0B)!"3H1O#__XN`<`$``(M8
M!*%(+@4(B00DZ##P__^+@/@#``")0R"A2"X%"(D$).@:\/__BX!P`0``BU@$
MH4@N!0B)!"3H!/#__S'2BX@,!@``A<ET%J%(+@4(B00DZ.OO__^+@`P&``"+
M4'"A2"X%"(E3)(D$).C2[___BX!P`0``BT`$QT`H`````*%(+@4(B00DZ+7O
M__^+@'`!``"+0`3'0!@`````H4@N!0B)!"3HF.___XN`<`$``(M8!*%(+@4(
MB00DZ(+O__^+@'@!``")0RR#Q!1;7L.-=@"![)P```"%P(F\))0```")QXF<
M)(P```")M"20````B:PDF````'0%@#@`=2.+G"2,````B[0DD````(N\))0`
M``"+K"28````@<2<````PXD$).A8[___A<")QG3/9I")-"3HN.[__X7`B<,/
MA*8```"`>Q,N#X2T````B3PD@\,3Z"GM__^)'"2)Q>@?[?__C40%`HD$).BC
M[/__B5PD%(E\)!#'1"0,(,4$",=$)`C_____QT0D!`$```")Q8D$).CY[O__
MC40D((E$)`B);"0$QP0D`P```.B![O__@_C_=!"+1"0P)0#P```]`$```'1D
MB2PDZ'3K__^)+"3HW.K__XDT).@4[O__A<")PP^%7/___V:0B30DZ(#N__^)
M/"3H^.K__^D`____C78`@'L4``^$)O___X![%"YFD`^%-O___X![%0`/A!#_
M___I)____XUV`(GHZ*'^__^0ZYJ-M"8`````C;PG`````%:)QE,QVX/L%*%(
M+@4(B00DZ.KM__^)="0$QP0D`P```(/`7(E$)`CHX^W__X7`=`^#Q!2)V%M>
MPXVT)@````"A2"X%"(D$).BS[?__BT!L)0#P```]`$```'0<H4@N!0B)!"3H
ME^W__XM`;"4`\```/0"@``!UN8DT)#';QT0D!`(```#HQNS__X7`#Y3#@\04
MB=A;7L.)]HV\)P````!55U:)QE,QP(/L/(G3@#H]#Y3``<.)'"3H@^O__XU4
M)"R)1"0<B?#H1/O__X7`B<</A.H```")!"3H8NO__S'2.40D'`^&M@```(M,
M)"S!X0(/M@8\/0^$=`$``(3`#X1L`0``B?#K!(32=`N#P`$/MA"`^CUU\2GP
MBU0D'(L]0"X%"(U$$`(!SXD$).B?ZO__A<")!P^$/`$``(M4)"RA0"X%"(L$
MD`^V%H32B!!T)(#Z/70?@\8!ZPN-M@````"`^CUT#P^V%H/``8/&`832B!!U
M[,8`/3'2C;0F``````^V#!.(3!`!@\(!A,EU\3'`@\0\6UY?7<.-M"8`````
M#[8$$X@$%X/"`83`=.$/M@03B`07@\(!A,!UY.O19I"++4`N!0@Q_[@(````
MBU4`A=)T%HUT)@"#QP&+3+T`A<EU]8T$O0@```"+%8`N!0B%TG0TB40D!(DL
M).C`Z?__A<")PJ-`+@4(=&R-#+T`````QT2Z!`````")?"0LZ<[^__^0C70F
M`,<%@"X%"`$```")!"3HENG__X7`=#F-#+T`````B4PD"(E,)!2);"0$B00D
MB40D&.@#Z/__BU0D&(M,)!2)%4`N!0CKI8UV`#'`Z:+^__^X_____^D0____
MZPV0D)"0D)"0D)"0D)"0@>P\$```B;PD-!```(U\)!R)G"0L$```B<.)K"0X
M$```B=5EH10```")A"0<$```,<")M"0P$```QT0D"/\/``")?"0$QP0D)L4$
M".A/Z/__A<`/CH<```"-</^`?#0<`'1UB<:)="0(QT0D!"\```")/"3HY^G_
M_X7`=&.A2"X%"(D$).CFZO__B70D#(E\)`B)7"0$B00DZ&+J__^+A"0<$```
M93,%%````'51BYPD+!```(NT)#`0``"+O"0T$```BZPD.!```('$/!```,.-
MM"8`````A?9UB8UT)@"A2"X%"(D$).B#ZO__B6PD"(E<)`2)!"3HL^?__^N?
MZ$SG__^-M@````"-OP````"#[!RA2"X%"(D$).A0ZO__QT0D##7%!`C'1"0(
M,),$",=$)`0_Q00(B00DZ,#H__^#Q!S#C;8`````C;\`````@^PLH4@N!0B)
M!"3H$.K__XD$).BH____H4@N!0B)!"3H^^G__\=$)!0`````QT0D$/_&!`C'
M1"0,_\8$",=$)`@POP0(QT0D!%O%!`B)!"3H"^G__X/$+,.-M"8`````@>P\
M(```B9PD,"```#';B;0D-"```(UT)"IEH10```")A"0L(```,<")O"0X(```
MZ"OG___'1"04,<4$",=$)`QPQ00(QT0D"`$0``#'1"0$`0```(DT)(E$)!#H
MK^G__X7`>$:-O"0K$```B30DQT0D"``0``")?"0$Z'#F__^%P(G&>"6-0`&)
M!"3H_^;__X7`B<-T%(ET)`B)?"0$B00DZ)GE___&!#,`BY0D+"```&4S%10`
M``")V'4<BYPD,"```(NT)#0@``"+O"0X(```@<0\(```P^C"Y?__9I#I&___
M_XUT)@"-O"<`````55=64X'L3!```&6A%````(F$)#P0```QP+A^Q00(BYPD
M8!```(NT)&00``#H7_?__\=$)`0O````B1PDB<7HK>;__X7`="V)VKB'Q00(
MZ!W[__^+E"0\$```93,5%````(G8#X56`0``@<1,$```6UY?7<.)'"3HE.;_
M_\=$)`24Q00(B30DB40D+.B@Y___A<")QW2QC70D/(VV`````(`_`'4%OWS%
M!`B%[704B7PD!(DL).A&Y/__A<`/A*L```")/"3H1N;__X!\!_\O=16-M"8`
M````@^@!@'P'_R_&!`<`=/*+5"0LC400`3W_#P``#X].____B5PD&,=$)!26
MQ00(B7PD$,=$)`RZQ@0(QT0D"``0``#'1"0$`0```(DT).CWY___H4@N!0B)
M!"3HFN?__XET)`3'!"0#````@\!<B40D".ASY___A<!U'*%(+@4(B00DZ'+G
M__^+0&PE`/```#T`@```="/'1"0$E,4$",<$)`````#HK^;__X7`B<</A17_
M___IM_[__\=$)`0!````B30DZ(#F__^%P'7)B?*XA\4$".C`^?__B30DZ-CE
M__^)P^F4_O__Z.SC__^-M@````"-OP````"+1"0$#[8(A,ET(HU0`>L+@\(!
M#[9*_X3)=!*`^2]U\(G0@\(!#[9*_X3)=>[SPY!3@^P8BUPD((7;=#2`.P!T
M+XD<).CWY/__C40#_SG#<A+K29"-="8`@^@!.=@/A(4```"`."]T\.LKC;8`
M````QP0D`@```.A4Y/__A<!T!6;'`"X`@\086\.-M@````"`."]T!X/H`3G#
M<O0YV'1(@^@!.<-S!8`X+W3TB<(QP"G:C4H"@?D`$```=\B#P@&)7"0$QT0D
M#``0``")5"0(QP0DH"X%".A$Y?__@\08N*`N!0A;PV:0@#@O=!''1"0@EL4$
M"(/$&%OIPN3__\<$)`(```#HQN/__XG",<"%T@^$;____V;'`BX`B=#I8___
M_XVT)@````"-O"<`````5U:#[#1EH10```")1"0L,<"A#,<$"(E$)`JA$,<$
M"(E$)`ZA%,<$"(E$)!*A&,<$"(E$)!:A',<$"(E$)!JA(,<$"(E$)!ZA),<$
M"(E$)"*A*,<$"(E$)"8/MP4LQP0(9HE$)"JXF,4$".@Q]/__N*'%!`CH)_3_
M_[BIQ00(Z!WT__^XLL4$".@3]/__N+G%!`CH"?3__[C)Q00(Z/_S__^X?L4$
M".CU\___N-7%!`CHZ_/__[C?Q00(Z.'S__^XZ<4$".C7\___N(?%!`CHS?/_
M_[CSQ00(Z,/S__^X_,4$".BY\___N`?&!`CHG_/__X7`=`R)PKC?Q00(Z&_W
M__^X&,8$".B%\___A<!T#(G"N"K&!`CH5??__[@UQ@0(Z&OS__^%P'0OB<*X
M?L4$".@[]___NF'&!`BXN<4$".@L]___BT0D+&4S!10```!U28/$-%Y?PY"X
M1<8$".@N\___A<!T$HG"N-7%!`CH_O;__^O!C70F`(UT)!N_5L8$"+D*````
M\Z9UJXU4)"6XU<4$".C8]O__ZYOH$>'__Y"#[`RA8-($"(/X_W0+@\0,PXVT
M)@````"XU<4$".C.\O__B<(QP(72=`\/MA*$TG0(,<"`^C`/E<"C8-($"(/$
M#,.-M"8`````C;PG`````(/L'.C(X/__B00DZ"#@__^%P'0,BP"#Q!S#C;8`
M````,<#K\HVV`````(V_`````%575E.[;<8$"(/L7(M\)'"-="0XQT0D-&W&
M!`C'1"0X8\8$",=$)#QPQ@0(QT0D0&;&!`C'1"1$:\8$",=$)$A]Q@0(QT0D
M3`````#K'&:0B7PD!(D$).ATW___A<!T.(/&!(M>_(7;="6)V.C_\?__A<")
MQ70%@#@`==2)V(/&!(GZZ,CU__^+7OR%VW7;@\1<6UY?7<.0B3PDZ%#A__^)
M+"2)1"0LZ$3A__^+5"0LC40"`HD$).C$X/__B6PD&,=$)!24Q00(B7PD$,=$
M)`RZQ@0(QT0D"/_____'1"0$`0```(D$)(E$)"SH$./__XM4)"R)V.A5]?__
MZ6#___]55U93@>P\@0``9:$4````B80D+($``#'`N'[%!`B+K"10@0``QT0D
M=)3&!`C'1"1X?,4$",=$)'P`````QT0D7"K&!`C'1"1@(\8$",=$)&29Q@0(
MQT0D:$#&!`C'1"1LH<8$",=$)'``````QX0D@````(C&!`C'A"2$````I<8$
M",>$)(@`````````Z-WP__^%P'0)@#@`#X50!```Z"O^__^%P(G##X1@!```
MB1PDZ#G@__^-1``!B00DZ+W?__^`.P")QW0XB<:-="8`#[8#@\,!B30D@\8"
MQT0D#*[&!`C'1"0(_____XE$)!#'1"0$`0```.@#XO__@#L`=<Z-="1@N"K&
M!`CK#8UV`(/&!(M&_(7`="[H4?#__X7`B<-TZX`X`'3FZ('S__^%P'3=B1PD
MZ#7@__^%P(G&=5"-M"8`````BUPD=#'VA=MT/X`[`+@!````=#6)QNL8BURT
M=(7;#X1$`0``@\8!@#L`#X0X`0``B=CH,?/__X7`=-V)'"3HY=___X7`=-&)
MQHDT).A7W___B?F+&8/!!(V3__[^_O?3(=J!XH"`@(!TZ??"@(```'4&P>H0
M@\$"`-*#V0,I^8V<`00$``")'"3HJM[__XE\)!S'1"08L\8$",=$)!26Q00(
MB70D$,=$)`RXQ@0(B40D1,=$)`C_____QT0D!`$```")!"3H[N#__XM$)$3'
M1"0$P`$``(D$).@ZW___@_C_#X2)````H4@N!0B)!"3H=.#__\<$)`,```"#
MP%R)1"0(BT0D1(E$)`3H:>#__X7`#X2A````BT0D1#';B40D$(M%`,=$)`AL
MQP0(QT0D!`$```")1"0,H40N!0B)!"3HX]___XN4)"R!``!E,Q44````B=@/
MA9T(``"!Q#R!``!;7E]=PV:0,?;IVO[__Y#HT][__XL`@_@1#X1G____B40D
M%(M$)$0QVXE$)!"+10#'1"0(,,<$",=$)`0!````B40D#*%$+@4(B00DZ';?
M___KD8UT)@"A2"X%"(D$).BCW___BT!L)0#P```]`$````^%/____Z%(+@4(
MB00DZ(/?__^+<'3H:]S__SG&#X4B____H4@N!0B)!"3H9M___XM`;"7_`0``
M/<`!```/A0+___^)'"3H&]W__XG#N&;&!`CH_^W__X7`#X3B`0``B00DZ._=
M__^)1"0$BT4`B00DZ%#V__^%P(E$)$`/A+\!``"+1"1`B00DZ$C=__^#^`-^
M,XM4)$"_P<8$"+D%````C70"_/.F=1V#^`0/A%\&``"+5"1`@'P"^R\/A%`&
M``"0C70F`.B;^O__A<!U((M$)$#'1"0$`````(D$).@3W?__A<")1"1(#X5>
M`0``NF'&!`BXU<4$".@X\?__,?;H,=S__\=$)!S_Q@0(QT0D%);%!`C'1"0,
MVL8$",=$)`C_____QT0D!`$```")1"08BT0D1(D<)(E$)!#HI=[__XM\)$3K
M58VT)@````#H(]W__X,X$759Z-G;__^#Q@''1"0@_\8$"(ET)!S'1"04EL4$
M"(E\)!#'1"0,Z,8$"(E$)!C'1"0(_____\=$)`0!````B1PDZ$K>___'1"0$
MP`$``(D<).B:W/__@_C_=)V+1"1$B00DZ$G:__^)VKA^Q00(Z&WP__^)'"3H
M%?K__^F=_?__B00DB40D/.@$^O__BT0D/(D$).AHW/__B</I?OW__[X!````
MN(C&!`CK$Y"-="8`BX2T@````(/&`87`="'H/>S__X7`=.F`.`!TY(D$).@L
MW/__A<!TV(G#Z6#[__^P#;N-Q@0(Z6#[__^+10")1"1`Z37^___'1"0,`@``
M`,=$)`3N____QT0D"/____^)!"3HN=K__XM$)$B-E"2,````QT0D"`8```")
M5"0$B00DZ$K9__^`O"2,`````'4.@+PDC0```$,/A.T$``"+1"1(QT0D#```
M``#'1"0$`````,=$)`@`````B00DZ%[:___'A"2,@````2-%9\>$))"```")
MJ\WOQX0DE(```/[<NIC'A"28@```=E0R$,>$))R```#PX=+#QX0DH(``````
M``#'A"2D@````````,>$).B`````````B5PD3&:0C80DC````(E$)`2+1"1(
MQT0D"`"```")!"3HD=C__X7`B<4/CG,!``"+E"2@@```C;0DJ(```(T$ZCG0
M#Y+"#[;2B80DH(```(GH`90DI(```,'H'0&$)*2```"+A"3H@```C90DC```
M`(E4)$"%P'1FND````")ZRG".=5^`HG3C;0DJ(````'PC90DC````(E<)`B)
M5"0$B00DZ$_8__^+A"3H@````=B#^$")A"3H@```#X5&____C90DC````"G=
M`=J-A"2,@```B50D0.B;WO__C78`@_T_#XZ3````BUPD0(GOD(L#@^]`B0:+
M0P2)1@2+0PB)1@B+0PR)1@R+0Q")1A"+0Q2)1A2+0QB)1AB+0QR)1AR+0R")
M1B"+0R2)1B2+0RB)1BB+0RR)1BR+0S")1C"+0S2)1C2+0SB)1CB+0SR#PT")
M1CR-A"2,@```Z!C>__^#_S]_BX/M0(GJP>H&C4(!P>`&`40D0,'B!BG5BU0D
M0,=$)`Q$````B6PD"(DT)(E4)`3HT-C__XFL).B```#I9/[__XM$)$B+7"1,
MB00DZ.3:__^+M"2@@```BZPDI(```(GPP>@#@^`_C5`!@_HXQH0$J(```(`/
MCU`"``"Z-P```"G"C80$J8```(E4)`C'1"0$`````(D$).@8V?__B>B)ZL'H
M&(B$)."```")Z,'H$(B$).&```")Z,'H"(B$).*```")\,'H&(B$).2```")
M\,'H$(B$).6```")\,'H"(B$).:```")\#'VB(0DYX```(V$)(R```"(E"3C
M@```C;PD[X```.@)W?__BY0DC(```(G1P>D8B<B(C"08@0``B='!Z1"(C"09
M@0``B=&(E"0;@0``BY0DD(```,'I"(B,)!J!``")T<'I&(B,)!R!``")T<'I
M$(B,)!V!``")T8B4)!^!``"+E"24@```P>D(B(PD'H$``(G1P>D8B(PD(($`
M`(G1P>D0B(PD(8$``(G1B)0D(X$``(N4))B```#!Z0B(C"0B@0``B='!Z1B(
MC"0D@0``B='!Z1"(C"0E@0``B=&(E"0G@0``BY0DG(```,'I"(B,)":!``")
MT<'I&(B,)"B!``")T<'I$(B,)"F!``")T<'I"(B,)"J!``"(E"0K@0``Z0@`
M```/MH0T&($```^VP(E$)!"-!'>#Q@''1"0,KL8$",=$)`C_____QT0D!`$`
M``")!"3H(]G__X/^%'7&QH0D%X$```#'1"0<_\8$"(E\)!B+1"1$QT0D%);%
M!`C'1"0,R\8$",=$)`C_____B40D$,=$)`0!````B1PDZ-K8___IH/K__XMM
M!(7M#X2J^?__B2PDZ++6__^#^`,/AIGY__^-=`7\O\;&!`BY!0```/.F#X6#
M^?__B6PD0.EZ^?__NC\````IPHV$!*F```")5"0(QT0D!`````")!"3HR-;_
M_XV$)(R```#H'-O__XV4)*B```"Y#@```#'`B=?SJ^F-_?__@+PDC@```$$/
MA07[__^`O"2/````0P^%]_K__X"\))````!(#X7I^O__@+PDD0```$4/A=OZ
M__^+1"1(QT0D#`(```#'1"0$QO___\=$)`C_____B00DZ#G5__^+1"1(C90D
MC````(E4)`3'1"0(*0```(D$).C*T___C90DC````,=$)!S_Q@0(B50D&.FX
M_O__9I#H2]3__XUT)@"-O"<`````55=64X/L'*%(+@4(B00DZ$S7___&@/D"
M```!N+G%!`CH^^7__X7`=`F`.#$/A)X"``#H6?'__Z%(+@4(B00DZ!S7___'
M1"0,"P```,=$)`@!````QT0D!/G&!`B)!"3HW-3__X7`#X3$````BT`,,?:+
M:!BAI#X%"(/X`0^.HP```+L!````ZS&-M"8`````BT<,B40D!*&@/@4(BP28
MB00DZ.G2__^%P'5UH:0^!0B#PP&#Q@$YV'YKH4@N!0B)!"3HF=;__\=$)`P`
M````B70D"(EL)`2)!"3H\=7__X7`=#V+./9'"01UI:%(+@4(B00DZ&C6___'
M1"0,`@```,=$)`@`````B7PD!(D$).B<T___Z7K___^-M"8`````H:0^!0B-
M4/\Y\@^$0`$``*%(+@4(B00DZ"/6___'1"0,!````,=$)`@!````QT0D!/[&
M!`B)!"3HX]/__X7`B<-T-8M`#(LPH4@N!0B)!"3HZ]7__\=$)`@`QP0(B70D
M!(D$).@7T___BT,,BQCV0PI`#X48`0``H4@N!0B)!"3HN]7__\=$)`P$````
MQT0D"`$```#'1"0$!<8$"(D$).A[T___A<")PW0VN(?%!`CH2^3__X7`B<8/
MA'D!``"+0PR+.*%(+@4(B00DZ&_5__^)="0(B7PD!(D$).B?TO__H4@N!0B)
M!"3H4M7__\:`^0(```"A2"X%"(D$).@^U?__QX!P!````````+A^Q00(Z.KC
M__^%P*.H/@4(#X2E````QT0D!,`!``")!"3HO=/__X/X$70.A<!T"H/X_Y`/
MA8$!``"#Q!Q;7E]=PV:0@_@!#XZW_O__NP$```!FD*%(+@4(@\,!B00DZ-#4
M__^);"0$B00DZ%31__\Y':0^!0A_W.F'_O__C;0F`````*%(+@4(B00DZ*/4
M__^)7"0$B00DZ*?3___IRO[__V:0@'@!``^$7?W__XVV`````.E-_?__C78`
MH:`^!0B)!"3HN_'__X7`HZ@^!0@/A-D```"+0PR+/:`^!0B+,/9&"01T;(M&
M#(E\)`2)!"3H7M'__XG&BT,,BQCV0PD$='Z+0PR)1"0(H:`^!0B)="0,BP#'
M!"3DQP0(B40D!.B/TO__C;0F`````*&@/@4(BSB+0PR+,*%(+@4(B00DZ._3
M__^)^HGPZ';H___I@O[__Z%(+@4(B00DZ-33___'1"0,`@```,=$)`@`````
MB70D!(D$).@(T?__Z6G___^A2"X%"(D$).BFT___QT0D#`(```#'1"0(````
M`(E<)`2)!"3HVM#__^E7____QP0DP,<$".CYT?__B40D#*&H/@4(B40D"*&@
M/@4(BP#'!"0,R`0(B40D!.C5T?__D(UT)@!64X/L%(MT)"")-"3H;^S__P^V
M$(G#A-)T(XU``>L,D(/``0^V4/^$TG02@/HO=?")PX/``0^V4/^$TG7NZ-[N
M__^%P'0@A?9T'(`^`(UV`'04QT0D!+/&!`B)'"3H#L___SG8=`:#Q!1;7L.#
MQ!2)\%M>Z6CC__^0C;0F`````(/L'*%(+@4(B00DZ,#2___'1"0$_____XD$
M).@@T/__H4@N!0B)!"3HH]+__\=$)`@`````QT0D!+"E!`B)!"3H6]+__X/$
M',.0D)"0D)"04^@T````@<,*#0``@^P0BX,D`0``B40D#(M$)"")1"0(BT0D
M'(E$)`2+1"08B00DZ,O/__^#Q!!;PXL<),.0D%575E/H\?___X'#QPP``(/L
M'(ML)#"-N^#^___H\\W__XV#X/[__RG'P?\"A?]T*3'VC;8`````BT0D.(DL
M)(E$)`B+1"0TB40D!/^4L^#^__^#Q@$Y_G7?@\0<6UY?7</K#9"0D)"0D)"0
MD)"0D)#SPY"0D)"0D)"0D)"0D)"058GE4X/L!*$`T`0(@_C_=!.[`-`$"&:0
M@^L$_]"+`X/X_W7T@\0$6UW#D)!3@^P(Z`````!;@<,;#```Z._3__^#Q`A;
MPP```P````$``@`E<R\E<P`O<')O8R]S96QF+V5X90!P97)L>'-I+F,`1'EN
M84QO861E<CHZ8F]O=%]$>6YA3&]A9&5R`$EN=&5R;F%L<SHZ4$%2.CI"3T]4
M`"]P<F]C+R5I+R5S`"X`4$%27U1%35``4$%27U!23T=.04U%`#H`+P!015),
M-4Q)0@!015),3$E"`%!%4DPU3U!4`%!%4DQ)3P!005)?24Y)5$E!3$E:140`
M4$%27U-005=.140`4$%27T-,14%.`%!!4E]$14)51P!005)?0T%#2$4`4$%2
M7T%21T,`4$%27T%21U9?,`!005)?1TQ/0D%,7T1%0E5'`%!!4E]'3$]"04Q?
M5$U01$E2`%!!4E]435!$25(`4$%27T=,3T)!3%]414U0`%!!4E]'3$]"04Q?
M0TQ%04X`4$%27T-,14%./0`Q`$Q)0E!!5$@`1%E,1%],24)205)97U!!5$@`
M4TA,24)?4$%42`!54T52`%-94U1%30`O=&UP`%1%35!$25(`5$U0`%5315).
M04U%`"4P,G@`<&%R+0`E<R5S)7,E<P!P87)L`"YP87(`)7,E<V-A8VAE+25S
M)7,`)7,E<W1E;7`M)74E<P`E<R5S=&5M<"TE=2TE=25S`$%21U8`&`!P97)L
M`"UE`"TM``!?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@(``````E
M<SH@8W)E871I;VX@;V8@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D
M("AE<G)N;STE:2D*```E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@
M=6YS869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A
M=&EO;BD*``!5;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I<F5C=&]R>0`````E
M<SH@97AE8W5T:6]N(&]F("5S(&9A:6QE9"`H97)R;F\])6DI"@``)7,Z(&-R
M96%T:6]N(&]F('!R:79A=&4@8V%C:&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE
M9"`H97)R;F\])6DI"@``````````````````@/___\]!`1L#._@````>````
M0,K__Q0!``"0SO__@`4``##1__\X`0``0-S__W@!``#PW/__S`$```#=___D
M`0``4-W__P@"``#`WO__-`(``##@__]@`@``T.#__Y@"``#`XO__V`(``-#C
M__\$`P``$.3__QP#``!PY/__-`,``%#E__]<`P``8.7__W`#```PY___L`,`
M`&#G___$`P``8.C__P`$````ZO__,`0``%#J__]0!```@.K__VP$``"`Z___
MK`0``-#V___P!```X/K__S`%``!@^___:`4``+#[__^L!0``ZOO__\P%``#P
M^___X`4``&#\__\<!@``%``````````!>E(``7P(`1L,!`2(`0``(````!P`
M```DR?__4`0````."$8.#$H/"W0$>``_&CLJ,B0B/````$````#PS___"0L`
M``!!#@B%`D,.#(<#1`X0A@1!#A2#!48.[`(#]0H.%$$.$,-!#@S&00X(QT$.
M!,4``%````"`````P-K__Z$`````00X(A0)!#@R'`T$.$(8$00X4@P5%#D`"
M5PH.%$$.$,-!#@S&00X(QT$.!,5$"W`.%$7##A!!Q@X,0<<."$'%#@0``!0`
M``#4````'-O__Q``````0PX@3`X$`"````#L````%-O__U``````00X(@P)%
M#B`"2`X(00X$PP```"@````0`0``0-O__VT!````00X(A@)!#@R#`T,.(`-E
M`0X,00X(PT$.!,8`*````#P!``"$W/__8@$```!&#J`!2X<#5X4"A@2#!6<*
M#@3%Q\;#00L````T````:`$``,C=__^7`````$$."(8"0PX,@P-%#B!K"@X,
M0PX(PT$.!,9("P)2#@Q#PPX(0<8.!#P```"@`0``,-[__^$!````00X(A0)!
M#@R'`T$.$(8$0PX4@P5%#E`"Z0H.%$$.$,-!#@S&00X(QT$.!,5("P`H````
MX`$``.#?__\$`0```$8.P"!+AP-)@P5)A0)IA@0"A`H.!,7'QL-("Q0````,
M`@``Q.#__S0`````0PX@<`X$`!0````D`@``[.#__UD`````0PXP`E4.!"0`
M```\`@``-.'__]X`````1@[`0$F#!$N&`U:'`@*H"@X$Q\;#00L0````9`(`
M`.SA__\%`````````#P```!X`@``Z.'__\0!````00X(A0)!#@R'`T$.$(8$
M00X4@P5&#N`@`F4*#A1!#A##00X,QD$.",=!#@3%00L0````N`(``'CC__\O
M`````````#@```#,`@``E./___(`````00X(@P)##B`"5`H."$$.!,-'"P)/
M"@X(1L,.!$,+4`H."$$.!,-%"P```"P````(`P``6.3__Y\!````00X(AP)!
M#@R&`T,.0`-/`0H.#$$.",9!#@3'0@L``!P````X`P``R.7__T(`````0PX0
M30H.!$@+:0X$````&````%@#``#XY?__)`````!##B!6"@X$1PL``#P```!T
M`P``#.;__P`!````00X(A0)!#@R'`T$.$(8$00X4@P5(#G`"A@H.%$$.$,-!
M#@S&00X(QT$.!,5""P!`````M`,``,SF__]%"P```$$."(4"00X,AP-!#A"&
M!$$.%(,%1@[0@@(#GP(*#A1!#A##00X,QD$.",=!#@3%0PL``#P```#X`P``
MV/'__PL$````00X(A0)!#@R'`T$.$(8$00X4@P5##C`#8@(*#A1!#A##00X,
MQD$.",=!#@3%0PLT````.`0``*CU__]X`````$$."(8"00X,@P-##B`"9`H.
M#$$.",-!#@3&00M##@Q##@C#00X$QA0```!P!```\/7__TD`````0PX@`D4.
M!"@```"(!```",G__^(!````00X(A0)"#05<@P2&`P-G`0K#0<9!#`0$Q4$+
M'````+0$``#\]?__.@````!!#@B#`DX.&&D."$$.!,,0````U`0``!;V__\$
M`````````#@```#H!```"/;__V$`````00X(A0)!#@R'`T$.$(8$00X4@P5.
M#C`"2@X400X0PT$.#,9!#@C'00X$Q1`````D!0``//;__P(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````#_____`````/____\```````````$````!`````0```,H!```!````
MU@$```$```#A`0```0```.L!```!````^0$```$````&`@```0```%4"```/
M````R0,```P```!DD@0(#0```/S$!`CU_O]OC($$"`4```!DB00(!@```.2"
M!`@*````3@4```L````0````%0`````````#````(-$$"`(````@`@``%```
M`!$````7````1)`$"!$````4D`0($@```#`````3````"````/[__V^$CP0(
M____;P(```#P__]OLHX$"```````````````````````````````````````
M```````````````````````````````4T`0(``````````"VD@0(QI($"-:2
M!`CFD@0(]I($"`:3!`@6DP0()I,$"#:3!`A&DP0(5I,$"&:3!`AVDP0(AI,$
M"):3!`BFDP0(MI,$",:3!`C6DP0(YI,$"/:3!`@&E`0(%I0$"":4!`@VE`0(
M1I0$"%:4!`AFE`0(=I0$"(:4!`B6E`0(II0$"+:4!`C&E`0(UI0$".:4!`CV
ME`0(!I4$"!:5!`@FE00(-I4$"$:5!`A6E00(9I4$"':5!`B&E00(EI4$"*:5
M!`BVE00(QI4$"-:5!`CFE00(]I4$"`:6!`@6E@0()I8$"#:6!`A&E@0(5I8$
M"&:6!`AVE@0(AI8$"):6!`BFE@0(MI8$",:6!`C6E@0(YI8$"```````````
M`````````````````````````````````````/____\`````````````````
M````````````````````(R$O=7-R+V)I;B]P97)L"F5V86P@)V5X96,@+W5S
M<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PH@("`@:68@,#L@(R!N;W0@
M<G5N;FEN9R!U;F1E<B!S;VUE('-H96QL"@IP86-K86=E(%]?<&%R7W!L.PH*
M(R`M+2T@5&AI<R!S8W)I<'0@;75S="!N;W0@=7-E(&%N>2!M;V1U;&5S(&%T
M(&-O;7!I;&4@=&EM92`M+2T*(R!U<V4@<W1R:6-T.PH*(VQI;F4@,34X"@IM
M>2`H)'!A<E]T96UP+"`D<')O9VYA;64L($!T;7!F:6QE*3L*14Y$('L@:68@
M*"1%3E9[4$%27T-,14%.?2D@>PH@("`@<F5Q=6ER92!&:6QE.CI496UP.PH@
M("`@<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*("`@(')E<75I<F4@1FEL93HZ
M4W!E8SL*("`@(&UY("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M
M92@D<&%R7W1E;7`I.PH@("`@;W5T<RAQ<7M296UO=FEN9R!F:6QE<R!I;B`B
M)'!A<E]T96UP(GTI.PH@("`@1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![
M("@@+60@*2`_(')M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M<"D["B`@("!R
M;61I<B`D<&%R7W1E;7`["B`@("`C($1O;B=T(')E;6]V92!T;W!D:7(@8F5C
M875S92!T:&ES(&-A=7-E<R!A(')A8V4@=VET:"!O=&AE<B!A<'!S"B`@("`C
M('1H870@87)E('1R>6EN9R!T;R!S=&%R="X*"B`@("!I9B`H+60@)'!A<E]T
M96UP("8F("1>3R!N92`G35-7:6XS,B<I('L*("`@("`@("`C(%-O;65T:&EN
M9R!W96YT('=R;VYG('5N;&EN:VEN9R!T:&4@=&5M<&]R87)Y(&1I<F5C=&]R
M>2X@(%1H:7,*("`@("`@("`C('1Y<&EC86QL>2!H87!P96YS(&]N('!L871F
M;W)M<R!T:&%T(&1I<V%L;&]W('5N;&EN:VEN9R!S:&%R960*("`@("`@("`C
M(&QI8G)A<FEE<R!A;F0@97AE8W5T86)L97,@=&AA="!A<F4@:6X@=7-E+B!5
M;FQI;FL@=VET:"!A(&)A8VMG<F]U;F0*("`@("`@("`C('-H96QL(&-O;6UA
M;F0@<V\@=&AE(&9I;&5S(&%R92!N;R!L;VYG97(@:6X@=7-E(&)Y('1H:7,@
M<')O8V5S<RX*("`@("`@("`C($1O;B=T(&1O(&%N>71H:6YG(&]N(%=I;F1O
M=W,@8F5C875S92!O=7(@<&%R96YT('!R;V-E<W,@=VEL;`H@("`@("`@(",@
M=&%K92!C87)E(&]F(&-L96%N:6YG('1H:6YG<R!U<"X*"B`@("`@("`@;7D@
M)'1M<"`](&YE=R!&:6QE.CI496UP*`H@("`@("`@("`@("!414U03$%412`]
M/B`G=&UP6%A86%@G+`H@("`@("`@("`@("!$25(@/3X@1FEL93HZ0F%S96YA
M;64Z.F1I<FYA;64H)'1O<&1I<BDL"B`@("`@("`@("`@(%-51D9)6"`]/B`G
M+F-M9"<L"B`@("`@("`@("`@(%5.3$E.2R`]/B`P+`H@("`@("`@("D["@H@
M("`@("`@('!R:6YT("1T;7`@(B,A+V)I;B]S:`IX/3$[('=H:6QE(%L@7"1X
M("UL="`Q,"!=.R!D;PH@("!R;2`M<F8@)R1P87)?=&5M<"<*("`@:68@6R!<
M(2`M9"`G)'!A<E]T96UP)R!=.R!T:&5N"B`@("`@("!B<F5A:PH@("!F:0H@
M("!S;&5E<"`Q"B`@('@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G(B`N("1T
M;7`M/F9I;&5N86UE("X@(B<*(CL*("`@("`@("`@("`@8VAM;V0@,#<P,"PD
M=&UP+3YF:6QE;F%M93L*("`@("`@("!M>2`D8VUD(#T@)'1M<"T^9FEL96YA
M;64@+B`G(#XO9&5V+VYU;&P@,CXF,2`F)SL*("`@("`@("!C;&]S92`D=&UP
M.PH@("`@("`@('-Y<W1E;2@D8VUD*3L*("`@("`@("!O=71S*'%Q*%-P87=N
M960@8F%C:V=R;W5N9"!P<F]C97-S('1O('!E<F9O<FT@8VQE86YU<#H@*0H@
M("`@("`@("`@("`@+B`D=&UP+3YF:6QE;F%M92D["B`@("!]"GT@?0H*0D5'
M24X@>PH@("`@26YT97)N86QS.CI005(Z.D)/3U0H*2!I9B!D969I;F5D("9)
M;G1E<FYA;',Z.E!!4CHZ0D]/5#L*"B`@("!E=F%L('L*"E]P87)?:6YI=%]E
M;G8H*3L*"FEF("AE>&ES=',@)$5.5GM005)?05)'5E\P?2!A;F0@)$5.5GM0
M05)?05)'5E\P?2`I('L*("`@($!!4D=6(#T@;6%P("1%3E9[(E!!4E]!4D=6
M7R1?(GTL("@Q("XN("1%3E9[4$%27T%21T-]("T@,2D["B`@("`D,"`]("1%
M3E9[4$%27T%21U9?,'T["GT*96QS92!["B`@("!F;W(@*&ME>7,@)45.5BD@
M>PH@("`@("`@(&1E;&5T92`D14Y6>R1??2!I9B`O7E!!4E]!4D=67R\["B`@
M("!]"GT*"FUY("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["@HC(&9I>"`D
M<')O9VYA;64@:68@:6YV;VME9"!F<F]M(%!!5$@*;7D@)4-O;F9I9R`]("@*
M("`@('!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G
M.B<I+`H@("`@7V5X92`@("`@("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3
M,GQC>6=W:6XI+R`_("<N97AE)R`Z("<G*2P*("`@(%]D96QI;2`@("`@(#T^
M("@D7D\@/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD["@I?<V5T
M7W!R;V=N86UE*"D["E]S971?<&%R7W1E;7`H*3L*"B,@36%G:6,@<W1R:6YG
M(&-H96-K:6YG(&%N9"!E>'1R86-T:6YG(&)U;F1L960@;6]D=6QE<R![>WL*
M;7D@*"1S=&%R=%]P;W,L("1D871A7W!O<RD["GL*("`@(&QO8V%L("1324=[
M7U]705).7U]](#T@<W5B('M].PH*("`@(",@0VAE8VL@9FEL92!T>7!E+"!G
M970@<W1A<G0@;V8@9&%T82!S96-T:6]N('M[>PH@("`@;W!E;B!?1D@L("<\
M)RP@)'!R;V=N86UE(&]R(&QA<W0["B`@("!B:6YM;V1E*%]&2"D["@H@("`@
M;7D@)&)U9CL*("`@('-E96L@7T9(+"`M."P@,CL*("`@(')E860@7T9(+"`D
M8G5F+"`X.PH@("`@;&%S="!U;FQE<W,@)&)U9B!E<2`B7&Y005(N<&U<;B([
M"@H@("`@<V5E:R!?1D@L("TQ,BP@,CL*("`@(')E860@7T9(+"`D8G5F+"`T
M.PH@("`@<V5E:R!?1D@L("TQ,B`M('5N<&%C:R@B3B(L("1B=68I+"`R.PH@
M("`@<F5A9"!?1D@L("1B=68L(#0["@H@("`@)&1A=&%?<&]S(#T@*'1E;&P@
M7T9(*2`M(#0["B`@("`C('U]?0H*("`@(",@17AT<F%C=&EN9R!E86-H(&9I
M;&4@:6YT;R!M96UO<GD@>WM["B`@("!M>2`E<F5Q=6ER95]L:7-T.PH@("`@
M=VAI;&4@*"1B=68@97$@(D9)3$4B*2!["B`@("`@("`@<F5A9"!?1D@L("1B
M=68L(#0["B`@("`@("`@<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B
M=68I.PH*("`@("`@("!M>2`D9G5L;&YA;64@/2`D8G5F.PH@("`@("`@(&]U
M=',H<7$H56YP86-K:6YG(&9I;&4@(B1F=6QL;F%M92(N+BXI*3L*("`@("`@
M("!M>2`D8W)C(#T@*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[.'TI+WQ\
M("D@/R`D,2`Z('5N9&5F.PH@("`@("`@(&UY("@D8F%S96YA;64L("1E>'0I
M(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*"B`@("`@("`@
M<F5A9"!?1D@L("1B=68L(#0["B`@("`@("`@<F5A9"!?1D@L("1B=68L('5N
M<&%C:R@B3B(L("1B=68I.PH*("`@("`@("!I9B`H9&5F:6YE9"@D97AT*2!A
M;F0@)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI('L*("`@("`@("`@
M("`@;7D@*"1O=70L("1F:6QE;F%M92D@/2!?=&5M<&9I;&4H)&5X="P@)&-R
M8RD["B`@("`@("`@("`@(&EF("@D;W5T*2!["B`@("`@("`@("`@("`@("!B
M:6YM;V1E*"1O=70I.PH@("`@("`@("`@("`@("`@<')I;G0@)&]U="`D8G5F
M.PH@("`@("`@("`@("`@("`@8VQO<V4@)&]U=#L*("`@("`@("`@("`@("`@
M(&-H;6]D(#`W-34L("1F:6QE;F%M93L*("`@("`@("`@("`@?0H@("`@("`@
M("`@("`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL
M96YA;64["B`@("`@("`@("`@("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I
M;&5N86UE?2`]("1F=6QL;F%M93L*("`@("`@("!]"B`@("`@("`@96QS:68@
M*"`D9G5L;&YA;64@/7X@;7Q>+S]S:&QI8B]\(&%N9"!D969I;F5D("1%3E9[
M4$%27U1%35!]("D@>PH@("`@("`@("`@("`C('-H;W5L9"!B92!M;W9E9"!T
M;R!?=&5M<&9I;&4H*0H@("`@("`@("`@("!M>2`D9FEL96YA;64@/2`B)$5.
M5GM005)?5$5-4'TO)&)A<V5N86UE)&5X="(["B`@("`@("`@("`@(&]U=',H
M(E-(3$E".B`D9FEL96YA;65<;B(I.PH@("`@("`@("`@("!O<&5N(&UY("1O
M=70L("<^)RP@)&9I;&5N86UE(&]R(&1I92`D(3L*("`@("`@("`@("`@8FEN
M;6]D92@D;W5T*3L*("`@("`@("`@("`@<')I;G0@)&]U="`D8G5F.PH@("`@
M("`@("`@("!C;&]S92`D;W5T.PH@("`@("`@('T*("`@("`@("!E;'-E('L*
M("`@("`@("`@("`@)')E<75I<F5?;&ES='LD9G5L;&YA;65](#T*("`@("`@
M("`@("`@)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R1F=6QL;F%M97T@/2![
M"B`@("`@("`@("`@("`@("!B=68@/3X@)&)U9BP*("`@("`@("`@("`@("`@
M(&-R8R`]/B`D8W)C+`H@("`@("`@("`@("`@("`@;F%M92`]/B`D9G5L;&YA
M;64L"B`@("`@("`@("`@('T["B`@("`@("`@?0H@("`@("`@(')E860@7T9(
M+"`D8G5F+"`T.PH@("`@?0H@("`@(R!]?7T*"B`@("!L;V-A;"!`24Y#(#T@
M*'-U8B!["B`@("`@("`@;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?.PH*("`@
M("`@("!R971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M;V1U;&4["@H@("`@
M("`@(&UY("1F:6QE;F%M92`](&1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U
M;&5]('Q\(&1O('L*("`@("`@("`@("`@;7D@)&ME>3L*("`@("`@("`@("`@
M9F]R96%C:"`H:V5Y<R`E<F5Q=6ER95]L:7-T*2!["B`@("`@("`@("`@("`@
M("!N97AT('5N;&5S<R`O7%$D;6]D=6QE7$4D+SL*("`@("`@("`@("`@("`@
M("1K97D@/2`D7SL@;&%S=#L*("`@("`@("`@("`@?0H@("`@("`@("`@("!D
M96QE=&4@)')E<75I<F5?;&ES='LD:V5Y?2!I9B!D969I;F5D*"1K97DI.PH@
M("`@("`@('T@;W(@<F5T=7)N.PH*("`@("`@("`D24Y#>R1M;V1U;&5](#T@
M(B]L;V%D97(O)&9I;&5N86UE+R1M;V1U;&4B.PH*("`@("`@("!I9B`H)$5.
M5GM005)?0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PH@
M("`@("`@("`@("!M>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@
M9&EE("0A.PH@("`@("`@("`@("!B:6YM;V1E*"1F:"D["B`@("`@("`@("`@
M('!R:6YT("1F:"`D9FEL96YA;64M/GMB=69].PH@("`@("`@("`@("!S965K
M*"1F:"P@,"P@,"D["B`@("`@("`@("`@(')E='5R;B`D9F@["B`@("`@("`@
M?0H@("`@("`@(&5L<V4@>PH@("`@("`@("`@("!M>2`H)&]U="P@)&YA;64I
M(#T@7W1E;7!F:6QE*"<N<&TG+"`D9FEL96YA;64M/GMC<F-]*3L*("`@("`@
M("`@("`@:68@*"1O=70I('L*("`@("`@("`@("`@("`@(&)I;FUO9&4H)&]U
M="D["B`@("`@("`@("`@("`@("!P<FEN="`D;W5T("1F:6QE;F%M92T^>V)U
M9GT["B`@("`@("`@("`@("`@("!C;&]S92`D;W5T.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@(&]P96X@;7D@)&9H+"`G/"<L("1N86UE(&]R(&1I92`D
M(3L*("`@("`@("`@("`@8FEN;6]D92@D9F@I.PH@("`@("`@("`@("!R971U
M<FX@)&9H.PH@("`@("`@('T*"B`@("`@("`@9&EE(")";V]T<W1R87!P:6YG
M(&9A:6QE9#H@8V%N;F]T(&9I;F0@)&UO9'5L92%<;B(["B`@("!]+"!`24Y#
M*3L*"B`@("`C($YO=R!L;V%D(&%L;"!B=6YD;&5D(&9I;&5S('M[>PH*("`@
M(",@:6YI=&EA;&EZ92!S:&%R960@;V)J96-T('!R;V-E<W-I;F<*("`@(')E
M<75I<F4@6%-,;V%D97(["B`@("!R97%U:7)E(%!!4CHZ2&5A=GD["B`@("!R
M97%U:7)E($-A<G`Z.DAE879Y.PH@("`@<F5Q=6ER92!%>'!O<G1E<CHZ2&5A
M=GD["B`@("!005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["@H@("`@
M(R!N;W<@;&5T)W,@=')Y(&=E='1I;F<@:&5L<&5R(&UO9'5L97,@9G)O;2!W
M:71H:6X*("`@(')E<75I<F4@24\Z.D9I;&4["@H@("`@(R!L;V%D(')E<W0@
M;V8@=&AE(&=R;W5P(&EN"B`@("!W:&EL92`H;7D@)&9I;&5N86UE(#T@*'-O
M<G0@:V5Y<R`E<F5Q=6ER95]L:7-T*5LP72D@>PH@("`@("`@("-L;V-A;"`D
M24Y#>R=#=V0N<&TG?2`](%]?1DE,15]?(&EF("1>3R!N92`G35-7:6XS,B<[
M"B`@("`@("`@=6YL97-S("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE
M(#U^("]"4T1004XO*2!["B`@("`@("`@("`@(",@<F5Q=6ER92!M;V1U;&5S
M+"!D;R!O=&AE<B!E>&5C=71A8FQE(&9I;&5S"B`@("`@("`@("`@(&EF("@D
M9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@>PH@("`@("`@("`@("`@("`@<F5Q
M=6ER92`D9FEL96YA;64["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS
M92!["B`@("`@("`@("`@("`@("`C(%-K:7`@06-T:79E4W1A=&4G<R!S:71E
M8W5S=&]M:7IE+G!L(&9I;&4Z"B`@("`@("`@("`@("`@("!D;R`D9FEL96YA
M;64@=6YL97-S("1F:6QE;F%M92`]?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*
M("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!D96QE=&4@)')E<75I
M<F5?;&ES='LD9FEL96YA;65].PH@("`@?0H*("`@(",@?7U]"@H@("`@;&%S
M="!U;FQE<W,@)&)U9B!E<2`B4$M<,#`S7#`P-"(["B`@("`D<W1A<G1?<&]S
M(#T@*'1E;&P@7T9(*2`M(#0["GT*(R!]?7T*"B,@07)G=6UE;G0@<')O8V5S
M<VEN9R![>WL*;7D@0'!A<E]A<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO
M9V9H+"`D8V%C:&5?;F%M92D["@ID96QE=&4@)$5.5GM005)?05!07U)%55-%
M?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE
M;2D*"B1Q=6EE="`](#`@=6YL97-S("1%3E9[4$%27T1%0E5'?3L*(R!$;VXG
M="!S=V%L;&]W(&%R9W5M96YT<R!F;W(@8V]M<&EL960@97AE8W5T86)L97,@
M=VET:&]U="`M+7!A<BUO<'1I;VYS"FEF("@A)'-T87)T7W!O<R!O<B`H)$%2
M1U9;,%T@97$@)RTM<&%R+6]P=&EO;G,G("8F('-H:69T*2D@>PH@("`@;7D@
M)61I<W1?8VUD(#T@<7<H"B`@("`@("`@<"`@(&)L:6)?=&]?<&%R"B`@("`@
M("`@:2`@(&EN<W1A;&Q?<&%R"B`@("`@("`@=2`@('5N:6YS=&%L;%]P87(*
M("`@("`@("!S("`@<VEG;E]P87(*("`@("`@("!V("`@=F5R:69Y7W!A<@H@
M("`@*3L*"B`@("`C(&EF('1H92!A<'`@:7,@:6YV;VME9"!A<R`B87!P;F%M
M92`M+7!A<BUO<'1I;VYS("TM<F5U<V4@4%)/1U)!32!`4%)/1U]!4D=6(BP*
M("`@(",@=7-E('1H92!A<'`@=&\@<G5N('1H92!G:79E;B!P97)L(&-O9&4@
M:6YS=&5A9"!O9B!A;GET:&EN9R!F<F]M('1H90H@("`@(R!A<'`@:71S96QF
M("AB=70@<W1I;&P@<V5T('5P('1H92!N;W)M86P@87!P(&5N=FER;VYM96YT
M(&%N9"!`24Y#*0H@("`@:68@*$!!4D=6(&%N9"`D05)'5ELP72!E<2`G+2UR
M975S92<I('L*("`@("`@("!S:&EF="!`05)'5CL*("`@("`@("`D14Y6>U!!
M4E]!4%!?4D554T5](#T@<VAI9G0@0$%21U8["B`@("!]"B`@("!E;'-E('L@
M(R!N;W)M86P@<&%R;"!B96AA=FEO=7(*"B`@("`@("`@;7D@0&%D9%]T;U]I
M;F,["B`@("`@("`@=VAI;&4@*$!!4D=6*2!["B`@("`@("`@("`@("1!4D=6
M6S!=(#U^("]>+2A;04E-3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["@H@
M("`@("`@("`@("!I9B`H)#$@97$@)TDG*2!["B`@("`@("`@("`@("`@("!P
M=7-H($!A9&1?=&]?:6YC+"`D,CL*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!E;'-I9B`H)#$@97$@)TTG*2!["B`@("`@("`@("`@("`@("!E=F%L(")U
M<V4@)#(B.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<VEF("@D,2!E
M<2`G02<I('L*("`@("`@("`@("`@("`@('5N<VAI9G0@0'!A<E]A<F=S+"`D
M,CL*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-I9B`H)#$@97$@)T\G
M*2!["B`@("`@("`@("`@("`@("`D;W5T(#T@)#(["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@96QS:68@*"0Q(&5Q("=B)RD@>PH@("`@("`@("`@("`@
M("`@)&)U;F1L92`]("=S:71E)SL*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!E;'-I9B`H)#$@97$@)T(G*2!["B`@("`@("`@("`@("`@("`D8G5N9&QE
M(#T@)V%L;"<["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS:68@*"0Q
M(&5Q("=Q)RD@>PH@("`@("`@("`@("`@("`@)'%U:65T(#T@,3L*("`@("`@
M("`@("`@?0H@("`@("`@("`@("!E;'-I9B`H)#$@97$@)TPG*2!["B`@("`@
M("`@("`@("`@("!O<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE(")86%@Z
M($-A;FYO="!O<&5N(&QO9SH@)"$B.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@(&5L<VEF("@D,2!E<2`G5"<I('L*("`@("`@("`@("`@("`@("1C86-H
M95]N86UE(#T@)#(["B`@("`@("`@("`@('T*"B`@("`@("`@("`@('-H:69T
M*$!!4D=6*3L*"B`@("`@("`@("`@(&EF("AM>2`D8VUD(#T@)&1I<W1?8VUD
M>R0Q?2D@>PH@("`@("`@("`@("`@("`@9&5L971E("1%3E9[)U!!4E]414U0
M)WT["B`@("`@("`@("`@("`@("!I;FET7VEN8R@I.PH@("`@("`@("`@("`@
M("`@<F5Q=6ER92!005(Z.D1I<W0["B`@("`@("`@("`@("`@("`F>R)005(Z
M.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'5CL*("`@("`@("`@("`@("`@
M("9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8["B`@("`@("`@
M("`@("`@("!E>&ET.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@
M("!U;G-H:69T($!)3D,L($!A9&1?=&]?:6YC.PH@("`@?0I]"@HC(%A86"`M
M+2!A9&0@+2UP87(M9&5B=6<@<W5P<&]R="$*"B,@?7U]"@HC($]U='!U="!M
M;V1E("@M3RD@:&%N9&QI;F<@>WM["FEF("@D;W5T*2!["B`@("!["B`@("`@
M("`@(VQO8V%L("1)3D-[)T-W9"YP;2=](#T@7U]&24Q%7U\@:68@)%Y/(&YE
M("=-4U=I;C,R)SL*("`@("`@("!R97%U:7)E($E/.CI&:6QE.PH@("`@("`@
M(')E<75I<F4@07)C:&EV93HZ6FEP.PH@("`@?0H*("`@(&UY("1P87(@/2!S
M:&EF="A`05)'5BD["B`@("!M>2`D>FEP.PH*"B`@("!I9B`H9&5F:6YE9"`D
M<&%R*2!["B`@("`@("`@;W!E;B!M>2`D9F@L("<\)RP@)'!A<B!O<B!D:64@
M(D-A;FYO="!F:6YD("<D<&%R)SH@)"$B.PH@("`@("`@(&)I;FUO9&4H)&9H
M*3L*("`@("`@("!B;&5S<R@D9F@L("=)3SHZ1FEL92<I.PH*("`@("`@("`D
M>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B`@("`@("`@*"`D>FEP+3YR96%D
M1G)O;49I;&5(86YD;&4H)&9H+"`D<&%R*2`]/2!!<F-H:79E.CI::7`Z.D%:
M7T]+*"D@*0H@("`@("`@("`@("!O<B!D:64@(E)E860@)R1P87(G(&5R<F]R
M.B`D(2(["B`@("!]"@H*("`@(&UY("5E;G8@/2!D;R!["B`@("`@("`@:68@
M*"1Z:7`@86YD(&UY("1M971A(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N>6UL
M)RDI('L*("`@("`@("`@("`@)&UE=&$@/7X@<R\N*EYP87(Z)"\O;7,["B`@
M("`@("`@("`@("1M971A(#U^(',O7EQ3+BHO+VUS.PH@("`@("`@("`@("`D
M;65T82`]?B`O7B`@*%M>.ETK*3H@*"XK*20O;6<["B`@("`@("`@?0H@("`@
M?3L*"B`@("`C($]P96X@:6YP=70@86YD(&]U='!U="!F:6QE<R![>WL*("`@
M(&QO8V%L("0O(#T@7#0["@H@("`@:68@*&1E9FEN960@)'!A<BD@>PH@("`@
M("`@(&]P96X@4$%2+"`G/"<L("1P87(@;W(@9&EE("(D(3H@)'!A<B(["B`@
M("`@("`@8FEN;6]D92A005(I.PH@("`@("`@(&1I92`B)'!A<B!I<R!N;W0@
M82!005(@9FEL92(@=6YL97-S(#Q005(^(&5Q(")02UPP,#-<,#`T(CL*("`@
M('T*"B`@("!#<F5A=&50871H*"1O=70I(#L*("`@(`H@("`@;7D@)&9H(#T@
M24\Z.D9I;&4M/FYE=R@*("`@("`@("`D;W5T+`H@("`@("`@($E/.CI&:6QE
M.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]74D].3%DH*2!\($E/.CI&:6QE
M.CI/7U1254Y#*"DL"B`@("`@("`@,#<W-RP*("`@("D@;W(@9&EE("0A.PH@
M("`@8FEN;6]D92@D9F@I.PH*("`@("0O(#T@*&1E9FEN960@)&1A=&%?<&]S
M*2`_(%PD9&%T85]P;W,@.B!U;F1E9CL*("`@('-E96L@7T9(+"`P+"`P.PH@
M("`@;7D@)&QO861E<B`]('-C86QA<B`\7T9(/CL*("`@(&EF("@A)$5.5GM0
M05)?5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@
M>PH@("`@("`@(')E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PH@("`@
M("`@(%!!4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<)&QO861E
M<BP@)#`I"B`@("!]"B`@("!F;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E
M96YV*2!["B`@("`@("`@;7D@)'9A;"`]("1E;G9[)&ME>7T@;W(@;F5X=#L*
M("`@("`@("`D=F%L(#T@979A;"`D=F%L(&EF("1V86P@/7X@+UY;)R)=+SL*
M("`@("`@("!M>2`D;6%G:6,@/2`B7U]%3E9?4$%27R(@+B!U8R@D:V5Y*2`N
M(")?7R(["B`@("`@("`@;7D@)'-E="`](")005)?(B`N('5C*"1K97DI("X@
M(CTD=F%L(CL*("`@("`@("`D;&]A9&5R(#U^('-[)&UA9VEC*"`K*7U["B`@
M("`@("`@("`@("1M86=I8R`N("1S970@+B`H)R`G('@@*&QE;F=T:"@D,2D@
M+2!L96YG=&@H)'-E="DI*0H@("`@("`@('UE9SL*("`@('T*("`@("1F:"T^
M<')I;G0H)&QO861E<BD["B`@("`D+R`]('5N9&5F.PH@("`@(R!]?7T*"B`@
M("`C(%=R:71E(&)U;F1L960@;6]D=6QE<R![>WL*("`@(&EF("@D8G5N9&QE
M*2!["B`@("`@("`@<F5Q=6ER92!005(Z.DAE879Y.PH@("`@("`@(%!!4CHZ
M2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*("`@("`@("!I;FET7VEN8R@I
M.PH*("`@("`@("!R97%U:7)E7VUO9'5L97,H*3L*"B`@("`@("`@;7D@0&EN
M8R`]('-O<G0@>PH@("`@("`@("`@("!L96YG=&@H)&(I(#P]/B!L96YG=&@H
M)&$I"B`@("`@("`@?2!G<F5P('L*("`@("`@("`@("`@(2]"4T1004XO"B`@
M("`@("`@?2!G<F5P('L*("`@("`@("`@("`@*"1B=6YD;&4@;F4@)W-I=&4G
M*2!O<@H@("`@("`@("`@("`H)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL
M:6)E>'!](&%N9`H@("`@("`@("`@("`@)%\@;F4@)$-O;F9I9SHZ0V]N9FEG
M>W!R:79L:6)E>'!]*3L*("`@("`@("!]($!)3D,["@H@("`@("`@(",@1FEL
M92!E>&ES=',@=&5S="!A9&1E9"!T;R!F:7@@4E0@(S0Q-SDP.@H@("`@("`@
M(",@1G5N;GDL(&YO;BUE>&ES=&EN9R!E;G1R>2!I;B!?/"XN+BYA=71O+T-O
M;7!R97-S+U)A=R]:;&EB+V%U=&]S<&QI="YI>"X*("`@("`@("`C(%1H:7,@
M:7,@82!B86YD+6%I9"!F:7@@=VET:"!N;R!D965P97(@9W)A<W`@;V8@=&AE
M(&ES<W5E+@H@("`@("`@(",@4V]M96)O9'D@<&QE87-E(&=O('1H<F]U9V@@
M=&AE('!A:6X@;V8@=6YD97)S=&%N9&EN9R!W:&%T)W,@:&%P<&5N:6YG+`H@
M("`@("`@(",@22!F86EL960N("TM(%-T969F96X*("`@("`@("!M>2`E9FEL
M97,["B`@("`@("`@+UY?/"@N*RDD+R!A;F0@+64@)#$@86YD("1F:6QE<WLD
M,7TK*R!F;W(@:V5Y<R`E.CH["B`@("`@("`@)&9I;&5S>R1??2LK(&9O<B!V
M86QU97,@)4E.0SL*"B`@("`@("`@;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#
M;VYF:6=[;&EB7V5X='T["B`@("`@("`@;7D@)7=R:71T96X["@H@("`@("`@
M(&9O<F5A8V@@*'-O<G0@:V5Y<R`E9FEL97,I('L*("`@("`@("`@("`@;7D@
M*"1N86UE+"`D9FEL92D["@H@("`@("`@("`@("!F;W)E86-H(&UY("1D:7(@
M*$!I;F,I('L*("`@("`@("`@("`@("`@(&EF("@D;F%M92`]("1005(Z.DAE
M879Y.CI&=6QL0V%C:&5[)%]]*2!["B`@("`@("`@("`@("`@("`@("`@)&9I
M;&4@/2`D7SL*("`@("`@("`@("`@("`@("`@("!L87-T.PH@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@96QS:68@*"]>*%Q1)&1I<EQ%7"\H
M+BI;7D-C72DI7%HO:2D@>PH@("`@("`@("`@("`@("`@("`@("@D9FEL92P@
M)&YA;64I(#T@*"0Q+"`D,BD["B`@("`@("`@("`@("`@("`@("`@;&%S=#L*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&5L<VEF("AM(5XO
M;&]A9&5R+UM>+UTK+R@N*EM>0V-=*5Q:(2D@>PH@("`@("`@("`@("`@("`@
M("`@(&EF("AM>2`D<F5F(#T@)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R0Q
M?2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`H)&9I;&4L("1N86UE*2`]
M("@D<F5F+"`D,2D["B`@("`@("`@("`@("`@("`@("`@("`@(&QA<W0["B`@
M("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@(&5L<VEF
M("@M9B`B)&1I<B\D,2(I('L*("`@("`@("`@("`@("`@("`@("`@("`@*"1F
M:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["B`@("`@("`@("`@("`@
M("`@("`@("`@(&QA<W0["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("!]"@H@("`@("`@("`@("!N97AT('5N
M;&5S<R!D969I;F5D("1N86UE(&%N9"!N;W0@)'=R:71T96Y[)&YA;65]*RL[
M"B`@("`@("`@("`@(&YE>'0@:68@(7)E9B@D9FEL92D@86YD("1F:6QE(#U^
M("]<+EQ1)&QI8E]E>'1<120O.PH@("`@("`@("`@("!O=71S*"!J;VEN("(B
M+`H@("`@("`@("`@("`@("`@<7$H4&%C:VEN9R`B*2P@<F5F("1F:6QE(#\@
M)&9I;&4M/GMN86UE?2`Z("1F:6QE+`H@("`@("`@("`@("`@("`@<7$H(BXN
M+BD*("`@("`@("`@("`@*3L*"B`@("`@("`@("`@(&UY("1C;VYT96YT.PH@
M("`@("`@("`@("!I9B`H<F5F*"1F:6QE*2D@>PH@("`@("`@("`@("`@("`@
M)&-O;G1E;G0@/2`D9FEL92T^>V)U9GT["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@96QS92!["B`@("`@("`@("`@("`@("!O<&5N($9)3$4L("<\)RP@
M)&9I;&4@;W(@9&EE(")#86XG="!O<&5N("1F:6QE.B`D(2(["B`@("`@("`@
M("`@("`@("!B:6YM;V1E*$9)3$4I.PH@("`@("`@("`@("`@("`@)&-O;G1E
M;G0@/2`\1DE,13X["B`@("`@("`@("`@("`@("!C;&]S92!&24Q%.PH*("`@
M("`@("`@("`@("`@(%!!4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L
M>2A<)&-O;G1E;G0L("1F:6QE*0H@("`@("`@("`@("`@("`@("`@(&EF("$D
M14Y6>U!!4E]615)"051)37T@86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L
M*20O:3L*"B`@("`@("`@("`@("`@("!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT
M96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N86UE*3L*("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@;W5T<RAQ<2A7<FET=&5N(&%S("(D
M;F%M92(I*3L*("`@("`@("`@("`@)&9H+3YP<FEN="@B1DE,12(I.PH@("`@
M("`@("`@("`D9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@
M.2DI.PH@("`@("`@("`@("`D9F@M/G!R:6YT*'-P<FEN=&8H"B`@("`@("`@
M("`@("`@("`B)3`X>"\E<R(L($%R8VAI=F4Z.EII<#HZ8V]M<'5T94-20S,R
M*"1C;VYT96YT*2P@)&YA;64*("`@("`@("`@("`@*2D["B`@("`@("`@("`@
M("1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N="DI*3L*("`@
M("`@("`@("`@)&9H+3YP<FEN="@D8V]N=&5N="D["B`@("`@("`@?0H@("`@
M?0H@("`@(R!]?7T*"B`@("`C($YO=R!W<FET92!O=70@=&AE(%!!4B!A;F0@
M;6%G:6,@<W1R:6YG<R![>WL*("`@("1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE
M*"1F:"D@:68@)'II<#L*"B`@("`D8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C
M:&5?;F%M92P@,"P@-#`["B`@("!I9B`H(21C86-H95]N86UE(&%N9"!M>2`D
M;71I;64@/2`H<W1A="@D;W5T*2E;.5TI('L*("`@("`@("!M>2`D8W1X(#T@
M979A;"![(')E<75I<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H
M,2D@?0H@("`@("`@("`@("!\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(
M03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*("`@("`@("`@("`@?'P@979A;"![
M(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ340U+3YN97<@?3L*"B`@
M("`@("`@(R!7;W)K87)O=6YD(&9O<B!B=6<@:6X@1&EG97-T.CI32$$@-2XS
M."!A;F0@-2XS.0H@("`@("`@(&UY("1S:&%?=F5R<VEO;B`](&5V86P@>R`D
M1&EG97-T.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PH@("`@("`@(&EF("@D<VAA
M7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I
M('L*("`@("`@("`@("`@)&-T>"T^861D9FEL92@D;W5T+"`B8B(I(&EF("@D
M8W1X*3L*("`@("`@("!]"B`@("`@("`@96QS92!["B`@("`@("`@("`@(&EF
M("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD;W5T(BDI('L*("`@("`@("`@
M("`@("`@(&)I;FUO9&4H)&9H*3L*("`@("`@("`@("`@("`@("1C='@M/F%D
M9&9I;&4H)&9H*3L*("`@("`@("`@("`@("`@(&-L;W-E*"1F:"D["B`@("`@
M("`@("`@('T*("`@("`@("!]"@H@("`@("`@("1C86-H95]N86UE(#T@)&-T
M>"`_("1C='@M/FAE>&1I9V5S="`Z("1M=&EM93L*("`@('T*("`@("1C86-H
M95]N86UE("X](")<,"(@>"`H-#$@+2!L96YG=&@@)&-A8VAE7VYA;64I.PH@
M("`@)&-A8VAE7VYA;64@+CT@(D-!0TA%(CL*("`@("1F:"T^<')I;G0H)&-A
M8VAE7VYA;64I.PH@("`@)&9H+3YP<FEN="AP86-K*"=.)RP@)&9H+3YT96QL
M("T@;&5N9W1H*"1L;V%D97(I*2D["B`@("`D9F@M/G!R:6YT*")<;E!!4BYP
M;5QN(BD["B`@("`D9F@M/F-L;W-E.PH@("`@8VAM;V0@,#<U-2P@)&]U=#L*
M("`@(",@?7U]"@H@("`@97AI=#L*?0HC('U]?0H*(R!0<F5P87)E("1P<F]G
M;F%M92!I;G1O(%!!4B!F:6QE(&-A8VAE('M[>PI["B`@("!L87-T('5N;&5S
M<R!D969I;F5D("1S=&%R=%]P;W,["@H@("`@7V9I>%]P<F]G;F%M92@I.PH*
M("`@(",@3F]W(&QO860@=&AE(%!!4B!F:6QE(&%N9"!P=70@:70@:6YT;R!0
M05(Z.DQI8D-A8VAE('M[>PH@("`@<F5Q=6ER92!005(["B`@("!005(Z.DAE
M879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["@H*("`@('L*("`@("`@("`C;&]C
M86P@)$E.0WLG0W=D+G!M)WT@/2!?7T9)3$5?7R!I9B`D7D\@;F4@)TU35VEN
M,S(G.PH@("`@("`@(')E<75I<F4@1FEL93HZ1FEN9#L*("`@("`@("!R97%U
M:7)E($%R8VAI=F4Z.EII<#L*("`@('T*("`@(&UY("1Z:7`@/2!!<F-H:79E
M.CI::7`M/FYE=SL*("`@(&UY("1F:"`]($E/.CI&:6QE+3YN97<["B`@("`D
M9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D:64@(B0A.B`D0"([
M"B`@("`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<')O9VYA;64I
M(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2!O<B!D:64@(B0A.B`D0"(["@H@
M("`@<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*("`@("1005(Z.DQI8D-A
M8VAE>R1P<F]G;F%M97T@/2`D>FEP.PH*("`@("1Q=6EE="`]("$D14Y6>U!!
M4E]$14)51WT["B`@("!O=71S*'%Q*%PD14Y6>U!!4E]414U0?2`]("(D14Y6
M>U!!4E]414U0?2(I*3L*"B`@("!I9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0
M?2D@>R`C('-H;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*("`@("`@("!F
M;W)E86-H(&UY("1M96UB97(@*"`D>FEP+3YM96UB97)S("D@>PH@("`@("`@
M("`@("!N97AT(&EF("1M96UB97(M/FES1&ER96-T;W)Y.PH@("`@("`@("`@
M("!M>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*("`@("`@
M("`@("`@;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["B`@("`@("`@
M("`@("`@("!>"B`@("`@("`@("`@("`@("`O/W-H;&EB+PH@("`@("`@("`@
M("`@("`@*#\Z)$-O;F9I9SHZ0V]N9FEG>W9E<G-I;VY]+RD_"B`@("`@("`@
M("`@("`@("`H/SHD0V]N9FEG.CI#;VYF:6=[87)C:&YA;65]+RD_"B`@("`@
M("`@("`@("`@("`H6UXO72LI"B`@("`@("`@("`@("`@("`D"B`@("`@("`@
M("`@('UX.PH@("`@("`@("`@("!M>2`D97AT<F%C=%]N86UE(#T@)#$["B`@
M("`@("`@("`@(&UY("1D97-T7VYA;64@/2!&:6QE.CI3<&5C+3YC871F:6QE
M*"1%3E9[4$%27U1%35!]+"`D97AT<F%C=%]N86UE*3L*("`@("`@("`@("`@
M:68@*"UF("1D97-T7VYA;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R
M97-S9613:7IE*"DI('L*("`@("`@("`@("`@("`@(&]U=',H<7$H4VMI<'!I
M;F<@(B1M96UB97)?;F%M92(@<VEN8V4@:70@86QR96%D>2!E>&ES=',@870@
M(B1D97-T7VYA;64B*2D["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("!O=71S*'%Q*$5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@
M(B1D97-T7VYA;64B*2D["B`@("`@("`@("`@("`@("`D;65M8F5R+3YE>'1R
M86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D["B`@("`@("`@("`@("`@("!C
M:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@97$@(FAP=7@B.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H@("`@?0H@("`@(R!]?7T*?0HC('U]?0H*
M(R!)9B!T:&5R92=S(&YO(&UA:6XN<&P@=&\@<G5N+"!S:&]W('5S86=E('M[
M>PIU;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*("`@(&1I
M92`\/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@
M72!;("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A
M;2YP;"!="B`@("`@("`D,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A
M<@HN"B`@("`D14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@/2`D,"`]
M('-H:69T*$!!4D=6*3L*?0HC('U]?0H*<W5B($-R96%T95!A=&@@>PH@("`@
M;7D@*"1N86UE*2`]($!?.PH@("`@"B`@("!R97%U:7)E($9I;&4Z.D)A<V5N
M86UE.PH@("`@;7D@*"1B87-E;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ
M0F%S96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI.PH@("`@"B`@
M("!R97%U:7)E($9I;&4Z.E!A=&@["B`@("`*("`@($9I;&4Z.E!A=&@Z.FUK
M<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A=&@@9&EE<R!W
M:71H(&5R<F]R"GT*"G-U8B!R97%U:7)E7VUO9'5L97,@>PH@("`@(VQO8V%L
M("1)3D-[)T-W9"YP;2=](#T@7U]&24Q%7U\@:68@)%Y/(&YE("=-4U=I;C,R
M)SL*"B`@("!R97%U:7)E(&QI8CL*("`@(')E<75I<F4@1'EN84QO861E<CL*
M("`@(')E<75I<F4@:6YT96=E<CL*("`@(')E<75I<F4@<W1R:6-T.PH@("`@
M<F5Q=6ER92!W87)N:6YG<SL*("`@(')E<75I<F4@=F%R<SL*("`@(')E<75I
M<F4@0V%R<#L*("`@(')E<75I<F4@0V%R<#HZ2&5A=GD["B`@("!R97%U:7)E
M($5R<FYO.PH@("`@<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["B`@("!R97%U
M:7)E($5X<&]R=&5R.PH@("`@<F5Q=6ER92!&8VYT;#L*("`@(')E<75I<F4@
M1FEL93HZ5&5M<#L*("`@(')E<75I<F4@1FEL93HZ4W!E8SL*("`@(')E<75I
M<F4@6%-,;V%D97(["B`@("!R97%U:7)E($-O;F9I9SL*("`@(')E<75I<F4@
M24\Z.DAA;F1L93L*("`@(')E<75I<F4@24\Z.D9I;&4["B`@("!R97%U:7)E
M($-O;7!R97-S.CI:;&EB.PH@("`@<F5Q=6ER92!!<F-H:79E.CI::7`["B`@
M("!R97%U:7)E(%!!4CL*("`@(')E<75I<F4@4$%2.CI(96%V>3L*("`@(')E
M<75I<F4@4$%2.CI$:7-T.PH@("`@<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D
M4W1R:7`["B`@("!R97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0[
M"B`@("!R97%U:7)E(&%T=')I8G5T97,["B`@("!E=F%L('L@<F5Q=6ER92!#
M=V0@?3L*("`@(&5V86P@>R!R97%U:7)E(%=I;C,R('T["B`@("!E=F%L('L@
M<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*("`@(&5V86P@>R!R97%U:7)E($%R
M8VAI=F4Z.E5N>FEP.CI"=7)S="!].PH@("`@979A;"![(')E<75I<F4@5&EE
M.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*("`@(&5V86P@>R!R97%U:7)E(%!E
M<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C86QA<B!].PI]"@HC(%1H92!#('9E
M<G-I;VX@;V8@=&AI<R!C;V1E(&%P<&5A<G,@:6X@;7EL9'(O;6MT;7!D:7(N
M8PHC(%1H:7,@8V]D92!A;'-O(&QI=F5S(&EN(%!!4CHZ4V5T=7!496UP(&%S
M('-E=%]P87)?=&5M<%]E;G8A"G-U8B!?<V5T7W!A<E]T96UP('L*("`@(&EF
M("AD969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]
M?B`O*"XK*2\I('L*("`@("`@("`D<&%R7W1E;7`@/2`D,3L*("`@("`@("!R
M971U<FX["B`@("!]"@H@("`@9F]R96%C:"!M>2`D<&%T:"`H"B`@("`@("`@
M*&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%35!$25(@
M5$5-4"!435`@*2DL"B`@("`@("`@<7<H($,Z7%Q414U0("]T;7`@+B`I"B`@
M("`I('L*("`@("`@("!N97AT('5N;&5S<R!D969I;F5D("1P871H(&%N9"`M
M9"`D<&%T:"!A;F0@+7<@)'!A=&@["B`@("`@("`@;7D@)'5S97)N86UE.PH@
M("`@("`@(&UY("1P=W5I9#L*("`@("`@("`C(&1O97,@;F]T('=O<FL@979E
M<GEW:&5R93H*("`@("`@("!E=F%L('LH)'!W=6ED*2`](&=E='!W=6ED*"0^
M*2!I9B!D969I;F5D("0^.WT["@H@("`@("`@(&EF("@@9&5F:6YE9"@F5VEN
M,S(Z.DQO9VEN3F%M92D@*2!["B`@("`@("`@("`@("1U<V5R;F%M92`]("97
M:6XS,CHZ3&]G:6Y.86UE.PH@("`@("`@('T*("`@("`@("!E;'-I9B`H9&5F
M:6YE9"`D<'=U:60I('L*("`@("`@("`@("`@)'5S97)N86UE(#T@)'!W=6ED
M.PH@("`@("`@('T*("`@("`@("!E;'-E('L*("`@("`@("`@("`@)'5S97)N
M86UE(#T@)$5.5GM54T523D%-17T@?'P@)$5.5GM54T52?2!\?"`G4UE35$5-
M)SL*("`@("`@("!]"B`@("`@("`@)'5S97)N86UE(#U^(',O7%<O7R]G.PH*
M("`@("`@("!M>2`D<W1M<&1I<B`]("(D<&%T:"1#;VYF:6=[7V1E;&EM?7!A
M<BTD=7-E<FYA;64B.PH@("`@("`@(&UK9&ER("1S=&UP9&ER+"`P-S4U.PH@
M("`@("`@(&EF("@A)$5.5GM005)?0TQ%04Y](&%N9"!M>2`D;71I;64@/2`H
M<W1A="@D<')O9VYA;64I*5LY72D@>PH@("`@("`@("`@("!O<&5N("AM>2`D
M9F@L("(\(BX@)'!R;V=N86UE*3L*("`@("`@("`@("`@<V5E:R`D9F@L("TQ
M."P@,CL*("`@("`@("`@("`@<WES<F5A9"`D9F@L(&UY("1B=68L(#8["B`@
M("`@("`@("`@(&EF("@D8G5F(&5Q(")<,$-!0TA%(BD@>PH@("`@("`@("`@
M("`@("`@<V5E:R`D9F@L("TU."P@,CL*("`@("`@("`@("`@("`@('-Y<W)E
M860@)&9H+"`D8G5F+"`T,3L*("`@("`@("`@("`@("`@("1B=68@/7X@<R]<
M,"\O9SL*("`@("`@("`@("`@("`@("1S=&UP9&ER("X]("(D0V]N9FEG>U]D
M96QI;7UC86-H92TB("X@)&)U9CL*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!E;'-E('L*("`@("`@("`@("`@("`@(&UY("1C='@@/2!E=F%L('L@<F5Q
M=6ER92!$:6=E<W0Z.E-(03L@1&EG97-T.CI32$$M/FYE=R@Q*2!]"B`@("`@
M("`@("`@("`@("`@("`@?'P@979A;"![(')E<75I<F4@1&EG97-T.CI32$$Q
M.R!$:6=E<W0Z.E-(03$M/FYE=R!]"B`@("`@("`@("`@("`@("`@("`@?'P@
M979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ340U+3YN97<@
M?3L*"B`@("`@("`@("`@("`@("`C(%=O<FMA<F]U;F0@9F]R(&)U9R!I;B!$
M:6=E<W0Z.E-(02`U+C,X(&%N9"`U+C,Y"B`@("`@("`@("`@("`@("!M>2`D
M<VAA7W9E<G-I;VX@/2!E=F%L('L@)$1I9V5S=#HZ4TA!.CI615)324].('T@
M?'P@,#L*("`@("`@("`@("`@("`@(&EF("@D<VAA7W9E<G-I;VX@97$@)S4N
M,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*("`@("`@("`@("`@
M("`@("`@("`D8W1X+3YA9&1F:6QE*"1P<F]G;F%M92P@(F(B*2!I9B`H)&-T
M>"D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!E;'-E('L*
M("`@("`@("`@("`@("`@("`@("!I9B`H)&-T>"!A;F0@;W!E;BAM>2`D9F@L
M("(\)'!R;V=N86UE(BDI('L*("`@("`@("`@("`@("`@("`@("`@("`@8FEN
M;6]D92@D9F@I.PH@("`@("`@("`@("`@("`@("`@("`@("`D8W1X+3YA9&1F
M:6QE*"1F:"D["B`@("`@("`@("`@("`@("`@("`@("`@(&-L;W-E*"1F:"D[
M"B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H*("`@
M("`@("`@("`@("`@("1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H
M92TB("X@*"`D8W1X(#\@)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE("D["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@8VQO<V4H)&9H*3L*("`@("`@("!]
M"B`@("`@("`@96QS92!["B`@("`@("`@("`@("1%3E9[4$%27T-,14%.?2`]
M(#$["B`@("`@("`@("`@("1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UT
M96UP+20D(CL*("`@("`@("!]"@H@("`@("`@("1%3E9[4$%27U1%35!](#T@
M)'-T;7!D:7(["B`@("`@("`@;6MD:7(@)'-T;7!D:7(L(#`W-34["B`@("`@
M("`@;&%S=#L*("`@('T*"B`@("`D<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!
M4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"@IS=6(@
M7W1E;7!F:6QE('L*("`@(&UY("@D97AT+"`D8W)C*2`]($!?.PH@("`@;7D@
M*"1F:"P@)&9I;&5N86UE*3L*"B`@("`D9FEL96YA;64@/2`B)'!A<E]T96UP
M+R1C<F,D97AT(CL*"B`@("!I9B`H)$5.5GM005)?0TQ%04Y]*2!["B`@("`@
M("`@=6YL:6YK("1F:6QE;F%M92!I9B`M92`D9FEL96YA;64["B`@("`@("`@
M<'5S:"!`=&UP9FEL92P@)&9I;&5N86UE.PH@("`@?0H@("`@96QS92!["B`@
M("`@("`@<F5T=7)N("AU;F1E9BP@)&9I;&5N86UE*2!I9B`H+7(@)&9I;&5N
M86UE*3L*("`@('T*"B`@("!O<&5N("1F:"P@)SXG+"`D9FEL96YA;64@;W(@
M9&EE("0A.PH@("`@8FEN;6]D92@D9F@I.PH@("`@<F5T=7)N*"1F:"P@)&9I
M;&5N86UE*3L*?0H*(R!S86UE(&-O9&4@;&EV97,@:6X@4$%2.CI3971U<%!R
M;V=N86UE.CIS971?<')O9VYA;64*<W5B(%]S971?<')O9VYA;64@>PH@("`@
M:68@*&1E9FEN960@)$5.5GM005)?4%)/1TY!345](&%N9"`D14Y6>U!!4E]0
M4D]'3D%-17T@/7X@+R@N*RDO*2!["B`@("`@("`@)'!R;V=N86UE(#T@)#$[
M"B`@("!]"@H@("`@)'!R;V=N86UE('Q\/2`D,#L*"B`@("!I9B`H)$5.5GM0
M05)?5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-4'TI
M(#X](#`I('L*("`@("`@("`D<')O9VYA;64@/2!S=6)S='(H)'!R;V=N86UE
M+"!R:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI("L@,2D["B`@
M("!]"@H@("`@:68@*"$D14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD97@H)'!R
M;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#X](#`I('L*("`@("`@("!I9B`H
M;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["B`@("`@("`@("`@(')E
M='5R;B!I9B`M<R`D9F@["B`@("`@("`@?0H@("`@("`@(&EF("@M<R`B)'!R
M;V=N86UE)$-O;F9I9WM?97AE?2(I('L*("`@("`@("`@("`@)'!R;V=N86UE
M("X]("1#;VYF:6=[7V5X97T["B`@("`@("`@("`@(')E='5R;CL*("`@("`@
M("!]"B`@("!]"@H@("`@9F]R96%C:"!M>2`D9&ER("AS<&QI="`O7%$D0V]N
M9FEG>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@>PH@("`@("`@(&YE>'0@
M:68@97AI<W1S("1%3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q("1%3E9[4$%2
M7U1%35!].PH@("`@("`@("1D:7(@/7X@<R]<421#;VYF:6=[7V1E;&EM?5Q%
M)"\O.PH@("`@("`@("@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI
M;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](BDL(&QA<W0I"B`@("`@("`@("`@
M(&EF("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?
M97AE?2(["B`@("`@("`@*"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E
M;&EM?21P<F]G;F%M92(I+"!L87-T*0H@("`@("`@("`@("!I9B`M<R`B)&1I
M<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["B`@("!]"GT*"G-U8B!?9FEX
M7W!R;V=N86UE('L*("`@("0P(#T@)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]0
M4D]'3D%-17T["B`@("!I9B`H:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D
M96QI;7TI(#P@,"D@>PH@("`@("`@("1P<F]G;F%M92`]("(N)$-O;F9I9WM?
M9&5L:6U])'!R;V=N86UE(CL*("`@('T*"B`@("`C(%A86"`M(&AA8VL@=&\@
M;6%K92!05T0@=V]R:PH@("`@;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E
M=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"B`@("`@("`@("`@("`@("`Z("@H9&5F
M:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D*"D@.B!@<'=D
M8"D["B`@("!C:&]M<"@D<'=D*3L*("`@("1P<F]G;F%M92`]?B!S+UXH/SU<
M+EPN/UQ1)$-O;F9I9WM?9&5L:6U]7$4I+R1P=V0D0V]N9FEG>U]D96QI;7TO
M.PH*("`@("1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M93L*?0H*<W5B
M(%]P87)?:6YI=%]E;G8@>PH@("`@:68@*"`D14Y6>U!!4E])3DE424%,25I%
M1'TK*R`]/2`Q("D@>PH@("`@("`@(')E='5R;CL*("`@('T@96QS92!["B`@
M("`@("`@)$5.5GM005)?24Y)5$E!3$E:141](#T@,CL*("`@('T*"B`@("!F
M;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!
M344@05)'0R!!4D=67S`@*2`I('L*("`@("`@("!D96QE=&4@)$5.5GLG4$%2
M7R<N)%]].PH@("`@?0H@("`@9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@
M1$5"54<@+RD@>PH@("`@("`@("1%3E9[)U!!4E\G+B1??2`]("1%3E9[)U!!
M4E]'3$]"04Q?)RXD7WT@:68@97AI<W1S("1%3E9[)U!!4E]'3$]"04Q?)RXD
M7WT["B`@("!]"@H@("`@;7D@)'!A<E]C;&5A;B`](")?7T5.5E]005)?0TQ%
M04Y?7R`@("`@("`@("`@("`@("(["@H@("`@:68@*"1%3E9[4$%27U1%35!]
M*2!["B`@("`@("`@9&5L971E("1%3E9[4$%27T-,14%.?3L*("`@('T*("`@
M(&5L<VEF("@A97AI<W1S("1%3E9[4$%27T=,3T)!3%]#3$5!3GTI('L*("`@
M("`@("!M>2`D=F%L=64@/2!S=6)S='(H)'!A<E]C;&5A;BP@,3(@*R!L96YG
M=&@H(D-,14%.(BDI.PH@("`@("`@("1%3E9[4$%27T-,14%.?2`]("0Q(&EF
M("1V86QU92`]?B`O7E!!4E]#3$5!3CTH7%,K*2\["B`@("!]"GT*"G-U8B!O
M=71S('L*("`@(')E='5R;B!I9B`D<75I970["B`@("!I9B`H)&QO9V9H*2![
M"B`@("`@("`@<')I;G0@)&QO9V9H(")`7UQN(CL*("`@('T*("`@(&5L<V4@
M>PH@("`@("`@('!R:6YT(")`7UQN(CL*("`@('T*?0H*<W5B(&EN:71?:6YC
M('L*("`@(')E<75I<F4@0V]N9FEG.PH@("`@<'5S:"!`24Y#+"!G<F5P(&1E
M9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*("`@("`@("!A
M<F-H;&EB97AP('!R:79L:6)E>'`@<VET96%R8VAE>'`@<VET96QI8F5X<`H@
M("`@("`@('9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP"B`@("`I.PI]"@HC
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,*(R!4:&4@;6%I;B!P86-K86=E
M(&9O<B!S8W)I<'0@97AE8W5T:6]N"@IP86-K86=E(&UA:6X["@IR97%U:7)E
M(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!4CHZ9FEN9%]P87(["E!!4BT^:6UP
M;W)T*$!P87)?87)G<RD["@ID:64@<7$H<&%R+G!L.B!#86XG="!O<&5N('!E
M<FP@<V-R:7!T("(D<')O9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T
M;W)Y7&XI"B`@("!U;FQE<W,@+64@)'!R;V=N86UE.PH*9&\@)'!R;V=N86UE
M.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]42U]%6$E47UPH*%QD*RE<
M*2\I.PID:64@)$`@:68@)$`["@I].PH*)#HZ7U]%4E)/4B`]("1`(&EF("1`
M.PI]"@I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/4B`]?B]>7U1+7T58
M251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T524D]2(&EF("0Z.E]?15)23U([
M"@HQ.PH*(VQI;F4@,3`Q,0H*7U]%3D1?7PH`````1T-#.B`H1TY5*2`T+C8N
M,@``+G-H<W1R=&%B`"YI;G1E<G``+FYO=&4N04))+71A9P`N;F]T92YG;G4N
M8G5I;&0M:60`+F=N=2YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N9VYU+G9E<G-I
M;VX`+F=N=2YV97)S:6]N7W(`+G)E;"YD>6X`+G)E;"YP;'0`+FEN:70`+G1E
M>'0`+F9I;FD`+G)O9&%T80`N96A?9G)A;65?:&1R`"YE:%]F<F%M90`N8W1O
M<G,`+F1T;W)S`"YJ8W(`+F1Y;F%M:6,`+F=O=``N9V]T+G!L=``N9&%T80`N
M8G-S`"YC;VUM96YT````````````````````````````````````````````
M```````````````+`````0````(````T@00(-`$``!,```````````````$`
M````````$P````<````"````2($$"$@!```@```````````````$````````
M`"$````'`````@```&B!!`AH`0``)```````````````!``````````T````
M]O__;P(```",@00(C`$``%@!```%``````````0````$````/@````L````"
M````Y(($".0"``"`!@``!@````$````$````$````$8````#`````@```&2)
M!`AD"0``3@4``````````````0````````!.````____;P(```"RC@0(L@X`
M`-`````%``````````(````"````6P```/[__V\"````A(\$"(0/``"0````
M!@````(````$`````````&H````)`````@```!20!`@4$```,`````4`````
M````!`````@```!S````"0````(```!$D`0(1!```"`"```%````#`````0`
M```(````?`````$````&````9)($"&02```N```````````````$````````
M`'<````!````!@```*"2!`B@$@``4`0`````````````$`````0```""````
M`0````8```#PE@0(\!8```PN`````````````!``````````B`````$````&
M````_,0$"/Q$```:```````````````$`````````(X````!`````@```!C%
M!`@810``2`,`````````````"`````````"6`````0````(```!@R`0(8$@`
M`/P```````````````0`````````I`````$````"````7,D$"%Q)```X!0``
M```````````$`````````*X````!`````P````#0!`@`4```"```````````
M````!`````````"U`````0````,````(T`0("%````@```````````````0`
M````````O`````$````#````$-`$"!!0```$```````````````$````````
M`,$````&`````P```!30!`@44```"`$```8`````````!`````@```#*````
M`0````,````<T00('%$```0```````````````0````$````SP````$````#
M````(-$$""!1```<`0`````````````$````!````-@````!`````P```$#2
M!`A`4@``Y%L`````````````(`````````#>````"`````,```!`+@4()*X`
M`'`0`````````````"``````````XP````$````P`````````"2N```1````
M```````````!`````0````$````#```````````````UK@``[```````````
+`````0``````````
